@@ -55,7 +55,7 @@ es_parser_c::es_parser_c()
   , m_discard_actual_frames(false)
   , m_simple_picture_order{}
   , m_first_cleanup{true}
-  , m_all_i_slices_are_key_frames{hack_engaged(ENGAGE_ALL_I_SLICES_ARE_KEY_FRAMES)}
+  , m_all_i_slices_are_key_frames{mtx::hacks::is_engaged(mtx::hacks::ALL_I_SLICES_ARE_KEY_FRAMES)}
   , m_debug_keyframe_detection{"avc_parser|avc_keyframe_detection"}
   , m_debug_nalu_types{        "avc_parser|avc_nalu_types"}
   , m_debug_timestamps{        "avc_parser|avc_timestamps"}
@@ -126,7 +126,7 @@ es_parser_c::add_bytes(unsigned char *buffer,
                     | (unsigned int)cursor.get_char() <<  8
                     | (unsigned int)cursor.get_char();
 
-    while (1) {
+    while (true) {
       if (NALU_START_CODE == marker)
         marker_size = 4;
       else if (NALU_START_CODE == (marker & 0x00ffffff))
@@ -189,6 +189,13 @@ es_parser_c::flush() {
   cleanup();
 }
 
+void
+es_parser_c::clear() {
+  m_unparsed_buffer.reset();
+  m_have_incomplete_frame = false;
+  m_parsed_position       = 0;
+}
+
 void
 es_parser_c::add_timestamp(int64_t timestamp) {
   m_provided_timestamps.emplace_back(timestamp, m_stream_position);
@@ -452,7 +459,7 @@ es_parser_c::handle_sei_nalu(memory_cptr const &nalu) {
 
     r.skip_bits(8);
 
-    while (1) {
+    while (true) {
       int ptype = 0;
       int value;
       while ((value = r.get_bits(8)) == 0xff)
@@ -541,7 +548,7 @@ es_parser_c::parse_slice(memory_cptr const &nalu,
     mtx::bits::reader_c r(nalu->get_buffer(), nalu->get_size());
     r.enable_rbsp_mode();
 
-    memset(&si, 0, sizeof(si));
+    si = slice_info_t{};
 
     r.skip_bit();                   // forbidden_zero_bit
     si.nal_ref_idc = r.get_bits(2); // nal_ref_idc
@@ -661,7 +668,7 @@ es_parser_c::get_most_often_used_duration()
 
   mxdebug_if(m_debug_timestamps, boost::format("Duration frequency. Result: %1%, diff %2%. Best before adjustment: %3%. All: %4%\n")
              % best.first % best.second % most_often->first
-             % boost::accumulate(m_duration_frequency, std::string(""), [](std::string const &accu, std::pair<int64_t, int64_t> const &pair) {
+             % boost::accumulate(m_duration_frequency, ""s, [](std::string const &accu, std::pair<int64_t, int64_t> const &pair) {
                  return accu + (boost::format(" <%1% %2%>") % pair.first % pair.second).str();
                }));
 
