@@ -69,27 +69,37 @@ public:
 
 
   virtual memory_cptr compress(memory_cptr const &buffer) {
-    return do_compress(buffer);
+    return do_compress(buffer->get_buffer(), buffer->get_size());
+  }
+
+  virtual memory_cptr compress(unsigned char const *buffer,
+                               std::size_t size) {
+    return do_compress(buffer, size);
   }
-  virtual std::string compress(std::string const &buffer);
 
   virtual memory_cptr decompress(memory_cptr const &buffer) {
-    return do_decompress(buffer);
+    return do_decompress(buffer->get_buffer(), buffer->get_size());
   }
-  virtual std::string decompress(std::string const &buffer);
 
-  virtual void set_track_headers(KaxContentEncoding &c_encoding);
+  virtual memory_cptr decompress(unsigned char const *buffer,
+                                 std::size_t size) {
+    return do_decompress(buffer, size);
+  }
+
+  virtual void set_track_headers(libmatroska::KaxContentEncoding &c_encoding);
 
   static compressor_ptr create(compression_method_e method);
   static compressor_ptr create(const char *method);
   static compressor_ptr create_from_file_name(std::string const &file_name);
 
 protected:
-  virtual memory_cptr do_compress(memory_cptr const &buffer) {
-    return buffer;
+  virtual memory_cptr do_compress(unsigned char const *buffer,
+                                  std::size_t size) {
+    return memory_c::clone(buffer, size);
   }
-  virtual memory_cptr do_decompress(memory_cptr const &buffer) {
-    return buffer;
+  virtual memory_cptr do_decompress(unsigned char const *buffer,
+                                    std::size_t size) {
+    return memory_c::clone(buffer, size);
   }
 };
 
