@@ -18,6 +18,8 @@
 #include "common/list_utils.h"
 #include "common/strings/formatting.h"
 
+using namespace libmatroska;
+
 kax_content_encoding_t::kax_content_encoding_t()
   : order{}
   , type{}
@@ -40,14 +42,11 @@ content_decoder_c::content_decoder_c(KaxTrackEntry &ktentry)
   initialize(ktentry);
 }
 
-content_decoder_c::~content_decoder_c() {
-}
-
 bool
 content_decoder_c::initialize(KaxTrackEntry &ktentry) {
   encodings.clear();
 
-  KaxContentEncodings *kcencodings = FindChild<KaxContentEncodings>(&ktentry);
+  auto kcencodings = FindChild<KaxContentEncodings>(&ktentry);
   if (!kcencodings)
     return true;
 
