@@ -34,6 +34,7 @@
 #include "common/version.h"
 
 using namespace libebml;
+using namespace libmatroska;
 
 EbmlElement *
 empty_ebml_master(EbmlElement *e) {
@@ -662,3 +663,27 @@ bool
 must_be_present_in_master(EbmlElement const &element) {
   return must_be_present_in_master(element.Generic());
 }
+
+bool
+found_in(EbmlElement &haystack,
+         EbmlElement const *needle) {
+  if (!needle)
+    return false;
+
+  if (needle == &haystack)
+    return true;
+
+  auto master = dynamic_cast<EbmlMaster *>(&haystack);
+  if (!master)
+    return false;
+
+  for (auto &child : *master) {
+    if (child == needle)
+      return true;
+
+    if (dynamic_cast<EbmlMaster *>(child) && found_in(*child, needle))
+      return true;
+  }
+
+  return false;
+}
