@@ -351,10 +351,10 @@ vui_parameters_copy(mtx::bits::reader_c &r,
     unsigned int ar_type = r.get_bits(8);   // aspect_ratio_idc
 
     if (keep_ar_info) {
-      w.put_bit(1);                         // aspect_ratio_info_present_flag
+      w.put_bit(true);                      // aspect_ratio_info_present_flag
       w.put_bits(8, ar_type);               // aspect_ratio_idc
     } else
-      w.put_bit(0);                         // aspect_ratio_info_present_flag
+      w.put_bit(false);                     // aspect_ratio_info_present_flag
 
     sps.ar_found = true;
 
@@ -374,7 +374,7 @@ vui_parameters_copy(mtx::bits::reader_c &r,
 
   } else {
     sps.ar_found = false;
-    w.put_bit(0);
+    w.put_bit(false);
   }
 
   // copy the rest
@@ -393,7 +393,7 @@ vui_parameters_copy(mtx::bits::reader_c &r,
 
   if (   (r.get_remaining_bits() >= 68)
       && (r.peek_bits(21) == 0x100000))
-    w.put_bit(0);                    // invalid default display window, signal no default_display_window_flag
+    w.put_bit(false);                // invalid default display window, signal no default_display_window_flag
   else if (w.copy_bits(1, r) == 1) { // default_display_window_flag
     w.copy_unsigned_golomb(r);               // def_disp_win_left_offset
     w.copy_unsigned_golomb(r);               // def_disp_win_right_offset
@@ -465,6 +465,16 @@ sps_info_t::default_duration()
   return 1000000000ll * num_units_in_tick / time_scale;
 }
 
+void
+sps_info_t::clear() {
+  *this = sps_info_t{};
+}
+
+void
+pps_info_t::clear() {
+  *this = pps_info_t{};
+}
+
 void
 pps_info_t::dump() {
   mxinfo(boost::format("pps_info dump:\n"
@@ -476,6 +486,11 @@ pps_info_t::dump() {
          % checksum);
 }
 
+void
+vps_info_t::clear() {
+  *this = vps_info_t{};
+}
+
 bool
 parse_vps(memory_cptr const &buffer,
           vps_info_t &vps) {
@@ -484,7 +499,7 @@ parse_vps(memory_cptr const &buffer,
   mtx::bits::writer_c w{};
   unsigned int i, j;
 
-  memset(&vps, 0, sizeof(vps));
+  vps.clear();
 
   w.copy_bits(1, r);            // forbidden_zero_bit
   if (w.copy_bits(6, r) != HEVC_NALU_TYPE_VIDEO_PARAM)  // nal_unit_type
@@ -534,7 +549,7 @@ parse_vps(memory_cptr const &buffer,
     while (r.get_remaining_bits())
       w.copy_bits(1, r);        // vps_extension_data_flag
 
-  w.put_bit(1);
+  w.put_bit(true);
   w.byte_align();
 
   // Given we don't change the NALU while writing to w,
@@ -557,10 +572,9 @@ parse_sps(memory_cptr const &buffer,
   mtx::bits::writer_c w{};
   unsigned int i;
 
-  keep_ar_info = !hack_engaged(ENGAGE_REMOVE_BITSTREAM_AR_INFO);
-
-  memset(&sps, 0, sizeof(sps));
+  keep_ar_info = !mtx::hacks::is_engaged(mtx::hacks::REMOVE_BITSTREAM_AR_INFO);
 
+  sps.clear();
   sps.par_num  = 1;
   sps.par_den  = 1;
   sps.ar_found = false;
@@ -665,7 +679,7 @@ parse_sps(memory_cptr const &buffer,
     while (r.get_remaining_bits())
       w.copy_bits(1, r);  // sps_extension_data_flag
 
-  w.put_bit(1);
+  w.put_bit(true);
   w.byte_align();
 
   // We potentially changed the NALU data with regards to the handling of keep_ar_info.
@@ -692,7 +706,7 @@ parse_pps(memory_cptr const &buffer,
   try {
     mtx::bits::reader_c r(buffer->get_buffer(), buffer->get_size());
 
-    memset(&pps, 0, sizeof(pps));
+    pps.clear();
 
     r.skip_bits(1);                                // forbidden_zero_bit
     if (r.get_bits(6) != HEVC_NALU_TYPE_PIC_PARAM) // nal_unit_type
@@ -885,7 +899,7 @@ hevcc_to_nalus(const unsigned char *buffer,
     if (0x01 != mem.read_uint8())
       throw false;
 
-    mem.setFilePointer(4, seek_beginning);
+    mem.setFilePointer(4);
     size_t nal_size_size = 1 + (mem.read_uint8() & 3);
     if (2 > nal_size_size)
       throw false;
