@@ -131,7 +131,7 @@ kax_analyzer_c::_log_debug_message(const std::string &message) {
 
 bool
 kax_analyzer_c::analyzer_debugging_requested(const std::string &section) {
-  return m_debug || debugging_c::requested(std::string("kax_analyzer_") + section);
+  return m_debug || debugging_c::requested("kax_analyzer_"s + section);
 }
 
 void
@@ -295,7 +295,7 @@ kax_analyzer_c::process_internal() {
 
   // Find the EbmlHead element. Must be the first one.
   m_ebml_head.reset(static_cast<EbmlHead *>(m_stream->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFL)));
-  if (!m_ebml_head)
+  if (!m_ebml_head || !Is<EbmlHead>(*m_ebml_head))
     throw mtx::kax_analyzer_x(Y("Not a valid Matroska file (no EBML head found)"));
 
   EbmlElement *l0{};
@@ -1388,7 +1388,7 @@ kax_analyzer_c::read_meta_seek(uint64_t pos,
 
   m_meta_seeks_by_position[pos] = true;
 
-  m_file->setFilePointer(pos, seek_beginning);
+  m_file->setFilePointer(pos);
 
   int upper_lvl_el = 0;
   EbmlElement *l1  = m_stream->FindNextElement(EBML_CONTEXT(m_segment), upper_lvl_el, 0xFFFFFFFFL, true, 1);
