@@ -19,6 +19,14 @@
 # include <intrin.h>
 #endif
 
+#if HAVE_BOOST_INTEGER_COMMON_FACTOR_HPP
+# include <boost/integer/common_factor.hpp>
+#else
+# include <boost/math/common_factor.hpp>
+#endif
+
+#include "common/math_fwd.h"
+
 namespace mtx { namespace math {
 
 inline std::size_t
@@ -62,5 +70,3 @@ to_signed(Tsigned const &s) {
 }
 
 }}
-
-using int64_rational_c = boost::rational<int64_t>;
