@@ -27,12 +27,11 @@ mm_read_buffer_io_c::mm_read_buffer_io_c(mm_io_cptr const &in,
   , m_eof(false)
   , m_fill(0)
   , m_offset(0)
-  , m_size(buffer_size)
   , m_buffering(true)
   , m_debug_seek{"read_buffer_io|read_buffer_io_read"}
   , m_debug_read{"read_buffer_io|read_buffer_io_read"}
 {
-  setFilePointer(0, seek_beginning);
+  setFilePointer(in->getFilePointer());
 }
 
 mm_read_buffer_io_c::~mm_read_buffer_io_c() {
@@ -46,7 +45,7 @@ mm_read_buffer_io_c::getFilePointer() {
 
 void
 mm_read_buffer_io_c::setFilePointer(int64 offset,
-                                    seek_mode mode) {
+                                    libebml::seek_mode mode) {
   if (!m_buffering) {
     m_proxy_io->setFilePointer(offset, mode);
     return;
@@ -59,17 +58,17 @@ mm_read_buffer_io_c::setFilePointer(int64 offset,
   m_eof = false;
 
   switch (mode) {
-    case seek_beginning:
+    case libebml::seek_beginning:
       new_pos = offset;
       break;
 
-    case seek_current:
+    case libebml::seek_current:
       new_pos  = m_offset;
       new_pos += m_cursor;
       new_pos += offset;
       break;
 
-    case seek_end:
+    case libebml::seek_end:
       new_pos = static_cast<int64_t>(get_size()) + offset; // offsets from the end are negative already
       break;
 
@@ -87,7 +86,7 @@ mm_read_buffer_io_c::setFilePointer(int64 offset,
   int64_t previous_pos = m_proxy_io->getFilePointer();
 
   // Actual seeking
-  m_proxy_io->setFilePointer(std::min(new_pos, get_size()), seek_beginning);
+  m_proxy_io->setFilePointer(std::min(new_pos, get_size()));
 
   // Get the actual offset from the underlying stream
   // Better be safe than sorry and use this instead of just taking
@@ -128,7 +127,7 @@ mm_read_buffer_io_c::_read(void *buffer,
       m_offset += m_cursor;
       m_cursor  = 0;
       m_fill    = 0;
-      avail     = std::min(get_size() - m_offset, static_cast<int64_t>(m_size));
+      avail     = std::min(get_size() - m_offset, static_cast<int64_t>(m_af_buffer->get_size()));
 
       if (!avail) {
         // must keep track of eof, as m_proxy_io->eof() will never be reached
@@ -168,3 +167,22 @@ mm_read_buffer_io_c::enable_buffering(bool enable) {
     m_fill   = 0;
   }
 }
+
+void
+mm_read_buffer_io_c::set_buffer_size(std::size_t new_buffer_size) {
+  if (new_buffer_size == m_af_buffer->get_size())
+    return;
+
+  m_af_buffer->resize(new_buffer_size);
+  m_buffer = m_af_buffer->get_buffer();
+
+  if (!m_buffering)
+    return;
+
+  auto previous_pos = getFilePointer();
+  m_offset          = previous_pos;
+  m_cursor          = 0;
+  m_fill            = 0;
+
+  m_proxy_io->setFilePointer(previous_pos);
+}
