@@ -26,7 +26,6 @@ protected:
   bool m_eof;
   size_t m_fill;
   int64_t m_offset;
-  const size_t m_size;
   bool m_buffering;
   debugging_option_c m_debug_seek, m_debug_read;
 
@@ -35,11 +34,12 @@ public:
   virtual ~mm_read_buffer_io_c();
 
   virtual uint64 getFilePointer();
-  virtual void setFilePointer(int64 offset, seek_mode mode = seek_beginning);
+  virtual void setFilePointer(int64 offset, libebml::seek_mode mode = libebml::seek_beginning);
   virtual int64_t get_size();
   inline virtual bool eof() { return m_eof; }
   virtual void clear_eof() { m_eof = false; }
   virtual void enable_buffering(bool enable);
+  virtual void set_buffer_size(std::size_t new_buffer_size = 1 << 17);
 
 protected:
   virtual uint32 _read(void *buffer, size_t size);
