@@ -15,12 +15,13 @@
 #include "common/common_pch.h"
 
 #include "common/mm_io_x.h"
+#include "common/mm_file_io.h"
+#include "common/mm_proxy_io.h"
 #include "common/mm_write_buffer_io.h"
 
-mm_write_buffer_io_c::mm_write_buffer_io_c(mm_io_c *out,
-                                           size_t buffer_size,
-                                           bool delete_out)
-  : mm_proxy_io_c(out, delete_out)
+mm_write_buffer_io_c::mm_write_buffer_io_c(mm_io_cptr const &out,
+                                           size_t buffer_size)
+  : mm_proxy_io_c{out}
   , m_af_buffer(memory_c::alloc(buffer_size))
   , m_buffer(m_af_buffer->get_buffer())
   , m_fill(0)
@@ -37,7 +38,7 @@ mm_write_buffer_io_c::~mm_write_buffer_io_c() {
 mm_io_cptr
 mm_write_buffer_io_c::open(const std::string &file_name,
                            size_t buffer_size) {
-  return mm_io_cptr(new mm_write_buffer_io_c(new mm_file_io_c(file_name, MODE_CREATE), buffer_size));
+  return std::make_shared<mm_write_buffer_io_c>(std::make_shared<mm_file_io_c>(file_name, MODE_CREATE), buffer_size);
 }
 
 uint64
@@ -47,11 +48,11 @@ mm_write_buffer_io_c::getFilePointer() {
 
 void
 mm_write_buffer_io_c::setFilePointer(int64 offset,
-                                     seek_mode mode) {
+                                     libebml::seek_mode mode) {
   int64_t new_pos
-    = seek_beginning == mode ? offset
-    : seek_end       == mode ? m_proxy_io->get_size() + offset // offsets from the end are negative already
-    :                          getFilePointer()       + offset;
+    = libebml::seek_beginning == mode ? offset
+    : libebml::seek_end       == mode ? m_proxy_io->get_size() + offset // offsets from the end are negative already
+    :                                   getFilePointer()       + offset;
 
   if (new_pos == static_cast<int64_t>(getFilePointer()))
     return;
