@@ -11,8 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef MTX_COMMON_OUTPUT_H
-#define MTX_COMMON_OUTPUT_H
+#pragma once
 
 #include "common/os.h"
 
@@ -24,8 +23,6 @@
 #include "common/locale.h"
 #include "common/mm_io.h"
 
-using namespace libebml;
-
 using mxmsg_handler_t = std::function<void(unsigned int level, std::string const &)>;
 void set_mxmsg_handler(unsigned int level, mxmsg_handler_t const &handler);
 
@@ -141,5 +138,3 @@ mxverb_tid(unsigned int level,
 extern const std::string empty_string;
 
 std::string fourcc_to_string(uint32_t fourcc);
-
-#endif  // MTX_COMMON_OUTPUT_H
