@@ -22,7 +22,7 @@
 #include "common/strings/parsing.h"
 #include "common/version.h"
 
-#define VERSIONNAME "At The End Of The World"
+#define VERSIONNAME "Prog Noir"
 
 version_number_t::version_number_t()
 {
@@ -179,7 +179,7 @@ parse_latest_release_version(mtx::xml::document_cptr const &doc) {
 
   for (auto arch : std::vector<std::string>{ "x86", "amd64" })
     for (auto package : std::vector<std::string>{ "installer", "portable" })
-      release.urls[std::string{"windows_"} + arch + "_" + package] = doc->select_node((std::string{"/mkvtoolnix-releases/latest-windows-binary/"} + package + "-url/" + arch).c_str()).node().child_value();
+      release.urls["windows_"s + arch + "_" + package] = doc->select_node(("/mkvtoolnix-releases/latest-windows-binary/"s + package + "-url/" + arch).c_str()).node().child_value();
 
   if (debugging_c::requested("version_check")) {
     std::stringstream urls;
@@ -195,8 +195,8 @@ segment_info_data_t
 get_default_segment_info_data(std::string const &application) {
   segment_info_data_t data{};
 
-  if (!hack_engaged(ENGAGE_NO_VARIABLE_DATA)) {
-    data.muxing_app   = (boost::format("libebml v%1% + libmatroska v%2%") % EbmlCodeVersion % KaxCodeVersion).str();
+  if (!mtx::hacks::is_engaged(mtx::hacks::NO_VARIABLE_DATA)) {
+    data.muxing_app   = (boost::format("libebml v%1% + libmatroska v%2%") % libebml::EbmlCodeVersion % libmatroska::KaxCodeVersion).str();
     data.writing_app  = get_version_info(application, static_cast<version_info_flags_e>(vif_full | vif_untranslated));
     data.writing_date = boost::posix_time::second_clock::universal_time();
 
