@@ -16,6 +16,7 @@
 #include <ebml/EbmlVoid.h>
 #include <matroska/KaxSegment.h>
 
+#include "common/at_scope_exit.h"
 #include "common/base64.h"
 #include "common/ebml.h"
 #include "common/mm_io_x.h"
@@ -25,6 +26,8 @@
 #include "common/strings/utf8.h"
 #include "common/xml/ebml_converter.h"
 
+using namespace libmatroska;
+
 namespace mtx { namespace xml {
 
 ebml_converter_c::limits_t::limits_t()
@@ -221,11 +224,11 @@ ebml_converter_c::parse_timestamp(parser_context_t &ctx) {
 
 void
 ebml_converter_c::parse_binary(parser_context_t &ctx) {
-  auto test_min_max = [&ctx](auto const &content) {
-    if (ctx.limits.has_min && (content.length() < static_cast<size_t>(ctx.limits.min)))
-      throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Minimum allowed length: %1%, actual length: %2%")) % ctx.limits.min % content.length()).str() };
-    if (ctx.limits.has_max && (content.length() > static_cast<size_t>(ctx.limits.max)))
-      throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Maximum allowed length: %1%, actual length: %2%")) % ctx.limits.max % content.length()).str() };
+  auto test_min_max = [&ctx](auto const &test_content) {
+    if (ctx.limits.has_min && (test_content.length() < static_cast<size_t>(ctx.limits.min)))
+      throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Minimum allowed length: %1%, actual length: %2%")) % ctx.limits.min % test_content.length()).str() };
+    if (ctx.limits.has_max && (test_content.length() > static_cast<size_t>(ctx.limits.max)))
+      throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Maximum allowed length: %1%, actual length: %2%")) % ctx.limits.max % test_content.length()).str() };
   };
 
   ctx.handled_attributes["format"] = true;
@@ -399,6 +402,8 @@ ebml_converter_c::convert_node_or_attribute_to_ebml(EbmlMaster &parent,
   std::string value = attribute ? attribute.value() : node.child_value();
   auto new_element  = verify_and_create_element(parent, name, node);
   auto limits       = m_limits.find(name);
+  auto is_ok        = false;
+  at_scope_exit_c cleanup([&new_element, &is_ok]() { if (!is_ok) delete new_element; });
 
   parser_context_t ctx { name, value, *new_element, node, handled_attributes, limits == m_limits.end() ? limits_t{} : limits->second };
 
@@ -420,6 +425,7 @@ ebml_converter_c::convert_node_or_attribute_to_ebml(EbmlMaster &parent,
   else if (!dynamic_cast<EbmlMaster *>(new_element))
     throw invalid_child_node_x{ name, get_tag_name(parent), node.offset_debug() };
 
+  is_ok = true;
   parent.PushElement(*new_element);
 
   return new_element;
@@ -500,7 +506,7 @@ ebml_converter_c::dump_semantics_recursively(int level,
     else
       limits_str = (boost::format("%2% <= %1%")                               % limits->second.max % label).str();
 
-    limits_str = std::string{", valid range: "} + limits_str;
+    limits_str = ", valid range: "s + limits_str;
   }
 
   auto type = dynamic_cast<EbmlMaster        *>(&element) ? "master"
