@@ -24,17 +24,14 @@
 #include "extract/options.h"
 #include "librmff/librmff.h"
 
-using namespace libebml;
-using namespace libmatroska;
-
 #define in_parent(p)                                                                     \
   (   !p->IsFiniteSize()                                                                 \
    || (in.getFilePointer() < (p->GetElementPosition() + p->HeadSize() + p->GetSize())))
 
 // Helper functions in mkvextract.cpp
-void show_element(EbmlElement *l, int level, const std::string &message);
+void show_element(libebml::EbmlElement *l, int level, const std::string &message);
 inline void
-show_element(EbmlElement *l,
+show_element(libebml::EbmlElement *l,
              int level,
              const boost::format &format) {
   show_element(l, level, format.str());
@@ -46,8 +43,8 @@ show_error(const boost::format &format) {
   show_error(format.str());
 }
 
-void find_and_verify_track_uids(KaxTracks &tracks, std::vector<track_spec_t> &tspecs);
-void write_cuesheet(std::string file_name, KaxChapters &chapters, KaxTags &tags, int64_t tuid, mm_io_c &out);
+void find_and_verify_track_uids(libmatroska::KaxTracks &tracks, std::vector<track_spec_t> &tspecs);
+void write_cuesheet(std::string file_name, libmatroska::KaxChapters &chapters, libmatroska::KaxTags &tags, int64_t tuid, mm_io_c &out);
 
 bool extract_tracks(kax_analyzer_c &analyzer, options_c::mode_options_c &options);
 bool extract_tags(kax_analyzer_c &analyzer, options_c::mode_options_c &options);
