@@ -23,7 +23,7 @@ public:
 public:
   xtr_aac_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
-  virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
+  virtual void create_file(xtr_base_c *master, libmatroska::KaxTrackEntry &track);
   virtual void handle_frame(xtr_frame_t &f);
 
   virtual const char *get_container_name() {
