@@ -33,10 +33,10 @@ xtr_avi_c::xtr_avi_c(const std::string &codec_id,
 
 void
 xtr_avi_c::create_file(xtr_base_c *master,
-                       KaxTrackEntry &track) {
+                       libmatroska::KaxTrackEntry &track) {
   init_content_decoder(track);
 
-  KaxCodecPrivate *priv = FindChild<KaxCodecPrivate>(&track);
+  auto priv = FindChild<libmatroska::KaxCodecPrivate>(&track);
   if (!priv)
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
 
@@ -62,7 +62,7 @@ xtr_avi_c::create_file(xtr_base_c *master,
     mxerror(boost::format(Y("The file '%1%' could not be opened for writing: %2%.\n")) % m_file_name % AVI_strerror());
 
   std::string writing_app = "mkvextract";
-  if (!hack_engaged(ENGAGE_NO_VARIABLE_DATA))
+  if (!mtx::hacks::is_engaged(mtx::hacks::NO_VARIABLE_DATA))
     writing_app += (boost::format(" %1%") % PACKAGE_VERSION).str();
   m_avi->writing_app = safestrdup(writing_app.c_str());
 
