@@ -31,10 +31,10 @@ xtr_hdmv_textst_c::xtr_hdmv_textst_c(const std::string &codec_id,
 
 void
 xtr_hdmv_textst_c::create_file(xtr_base_c *master,
-                               KaxTrackEntry &track) {
+                               libmatroska::KaxTrackEntry &track) {
   xtr_base_c::create_file(master, track);
 
-  auto priv = FindChild<KaxCodecPrivate>(&track);
+  auto priv = FindChild<libmatroska::KaxCodecPrivate>(&track);
   if (!priv)
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
 
@@ -62,7 +62,7 @@ xtr_hdmv_textst_c::create_file(xtr_base_c *master,
   if (mpriv->get_size() < static_cast<uint64_t>(3 + style_segment_size + (old_style ? 1 + 2 : 0)))
     mxerror(boost::format(Y("Track %1% CodecPrivate is too small.\n")) % m_tid);
 
-  m_out->write(std::string{"TextST"});
+  m_out->write("TextST"s);
 
   // The dialog style segment.
   m_out->write(&buf[style_segment_start], 3 + style_segment_size);
