@@ -34,8 +34,8 @@ xtr_flac_c::xtr_flac_c(const std::string &_codec_id,
 
 void
 xtr_flac_c::create_file(xtr_base_c *_master,
-                        KaxTrackEntry &track) {
-  KaxCodecPrivate *priv = FindChild<KaxCodecPrivate>(&track);
+                        libmatroska::KaxTrackEntry &track) {
+  auto priv = FindChild<libmatroska::KaxCodecPrivate>(&track);
   if (!priv)
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
 
@@ -59,19 +59,19 @@ xtr_oggbase_c::xtr_oggbase_c(const std::string &codec_id,
 
 void
 xtr_oggbase_c::create_file(xtr_base_c *master,
-                           KaxTrackEntry &track) {
+                           libmatroska::KaxTrackEntry &track) {
   m_sfreq = (int)kt_get_a_sfreq(track);
 
   xtr_base_c::create_file(master, track);
 
-  ogg_stream_init(&m_os, hack_engaged(ENGAGE_NO_VARIABLE_DATA) ? 1804289383 : random_c::generate_32bits() & 0x7ffff'ffff);
+  ogg_stream_init(&m_os, mtx::hacks::is_engaged(mtx::hacks::NO_VARIABLE_DATA) ? 1804289383 : random_c::generate_32bits() & 0x7ffff'ffff);
 }
 
 void
 xtr_oggbase_c::create_standard_file(xtr_base_c *master,
-                                    KaxTrackEntry &track,
-                                    LacingType lacing) {
-  KaxCodecPrivate *priv = FindChild<KaxCodecPrivate>(&track);
+                                    libmatroska::KaxTrackEntry &track,
+                                    libmatroska::LacingType lacing) {
+  auto priv = FindChild<libmatroska::KaxCodecPrivate>(&track);
   if (!priv)
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
 
@@ -81,7 +81,7 @@ xtr_oggbase_c::create_standard_file(xtr_base_c *master,
   std::vector<memory_cptr> header_packets;
 
   try {
-    if (lacing == LACING_NONE)
+    if (lacing == libmatroska::LACING_NONE)
       header_packets.push_back(mpriv);
 
     else {
@@ -176,7 +176,7 @@ xtr_oggbase_c::queue_frame(memory_cptr &frame,
 
   m_queued_granulepos = granulepos;
   m_queued_frame      = frame;
-  m_queued_frame->grab();
+  m_queued_frame->take_ownership();
 }
 
 void
@@ -222,8 +222,8 @@ xtr_oggvorbis_c::~xtr_oggvorbis_c() {
 
 void
 xtr_oggvorbis_c::create_file(xtr_base_c *master,
-                             KaxTrackEntry &track) {
-  create_standard_file(master, track, LACING_AUTO);
+                             libmatroska::KaxTrackEntry &track) {
+  create_standard_file(master, track, libmatroska::LACING_AUTO);
 }
 
 void
@@ -271,8 +271,8 @@ xtr_oggkate_c::xtr_oggkate_c(const std::string &codec_id,
 
 void
 xtr_oggkate_c::create_file(xtr_base_c *master,
-                           KaxTrackEntry &track) {
-  create_standard_file(master, track, LACING_AUTO);
+                           libmatroska::KaxTrackEntry &track) {
+  create_standard_file(master, track, libmatroska::LACING_AUTO);
 }
 
 void
@@ -324,8 +324,8 @@ xtr_oggtheora_c::xtr_oggtheora_c(const std::string &codec_id,
 
 void
 xtr_oggtheora_c::create_file(xtr_base_c *master,
-                             KaxTrackEntry &track) {
-  create_standard_file(master, track, LACING_AUTO);
+                             libmatroska::KaxTrackEntry &track) {
+  create_standard_file(master, track, libmatroska::LACING_AUTO);
 }
 
 void
@@ -364,14 +364,14 @@ xtr_oggopus_c::xtr_oggopus_c(const std::string &codec_id,
 
 void
 xtr_oggopus_c::create_file(xtr_base_c *master,
-                           KaxTrackEntry &track) {
-  create_standard_file(master, track, LACING_NONE);
+                           libmatroska::KaxTrackEntry &track) {
+  create_standard_file(master, track, libmatroska::LACING_NONE);
 }
 
 void
 xtr_oggopus_c::header_packets_unlaced(std::vector<memory_cptr> &header_packets) {
-  auto signature = std::string{"OpusTags"};
-  auto version   = std::string{"unknown encoder; extracted from Matroska with "} + (!hack_engaged(ENGAGE_NO_VARIABLE_DATA) ? get_version_info("mkvextract") : std::string{"mkvextract"});
+  auto signature = "OpusTags"s;
+  auto version   = "unknown encoder; extracted from Matroska with "s + (!mtx::hacks::is_engaged(mtx::hacks::NO_VARIABLE_DATA) ? get_version_info("mkvextract") : "mkvextract"s);
   auto ver_len   = version.length();
   auto mem       = memory_c::alloc(8 + 4 + ver_len + 4);
   auto buffer    = reinterpret_cast<char *>(mem->get_buffer());
