@@ -25,8 +25,8 @@ xtr_rmff_c::xtr_rmff_c(const std::string &codec_id,
 
 void
 xtr_rmff_c::create_file(xtr_base_c *master,
-                        KaxTrackEntry &track) {
-  KaxCodecPrivate *priv = FindChild<KaxCodecPrivate>(&track);
+                        libmatroska::KaxTrackEntry &track) {
+  auto priv = FindChild<libmatroska::KaxCodecPrivate>(&track);
   if (!priv)
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
 
