@@ -10,8 +10,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef MTX_XTR_TEXTSUBS_H
-#define MTX_XTR_TEXTSUBS_H
+#pragma once
 
 #include "common/common_pch.h"
 
@@ -27,7 +26,7 @@ public:
 public:
   xtr_srt_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
-  virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
+  virtual void create_file(xtr_base_c *master, libmatroska::KaxTrackEntry &track);
   virtual void handle_frame(xtr_frame_t &f);
 
   virtual const char *get_container_name() {
@@ -62,7 +61,7 @@ public:
 public:
   xtr_ssa_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
-  virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
+  virtual void create_file(xtr_base_c *master, libmatroska::KaxTrackEntry &track);
   virtual void handle_frame(xtr_frame_t &f);
   virtual void finish_file();
 
@@ -88,7 +87,7 @@ private:
 public:
   xtr_usf_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
-  virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
+  virtual void create_file(xtr_base_c *master, libmatroska::KaxTrackEntry &track);
   virtual void handle_frame(xtr_frame_t &f);
   virtual void finish_track();
   virtual void finish_file();
@@ -97,5 +96,3 @@ public:
     return "XML (USF text subtitles)";
   };
 };
-
-#endif
