@@ -60,15 +60,15 @@ xtr_vobsub_c::xtr_vobsub_c(const std::string &codec_id,
 
 void
 xtr_vobsub_c::create_file(xtr_base_c *master,
-                          KaxTrackEntry &track) {
-  KaxCodecPrivate *priv = FindChild<KaxCodecPrivate>(&track);
+                          libmatroska::KaxTrackEntry &track) {
+  auto priv = FindChild<libmatroska::KaxCodecPrivate>(&track);
   if (!priv)
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
 
   init_content_decoder(track);
 
   m_private_data = decode_codec_private(priv);
-  m_private_data->grab();
+  m_private_data->take_ownership();
 
   m_master   = master;
   m_language = kt_get_language(track);
@@ -128,6 +128,9 @@ xtr_vobsub_c::handle_frame(xtr_frame_t &f) {
   unsigned char *data = f.frame->get_buffer();
   size_t size         = f.frame->get_size();
 
+  if (size < 4)
+    return;
+
   m_positions.push_back(vmaster->m_out->getFilePointer());
   m_timestamps.push_back(f.timestamp);
 
