@@ -24,7 +24,7 @@ private:
 public:
   xtr_wav_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
-  virtual void create_file(xtr_base_c *master, KaxTrackEntry &track) override;
+  virtual void create_file(xtr_base_c *master, libmatroska::KaxTrackEntry &track) override;
   virtual void finish_file() override;
   virtual void handle_frame(xtr_frame_t &f) override;
 
@@ -44,7 +44,7 @@ private:
 public:
   xtr_wavpack4_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
-  virtual void create_file(xtr_base_c *master, KaxTrackEntry &track) override;
+  virtual void create_file(xtr_base_c *master, libmatroska::KaxTrackEntry &track) override;
   virtual void handle_frame(xtr_frame_t &f) override;
   virtual void finish_file() override;
 
