@@ -19,6 +19,8 @@
 #include "common/strings/formatting.h"
 #include "extract/xtr_webvtt.h"
 
+using namespace libmatroska;
+
 xtr_webvtt_c::xtr_webvtt_c(const std::string &codec_id,
                      int64_t tid,
                      track_spec_t &tspec)
@@ -61,7 +63,7 @@ xtr_webvtt_c::handle_frame(xtr_frame_t &f) {
       auto lines   = split(chomp(normalize_line_endings(content)), "\n", 3);
 
       if ((lines.size() > 0) && !lines[0].empty())
-        settings_list = std::string{" "} + boost::trim_copy(lines[0]);
+        settings_list = " "s + boost::trim_copy(lines[0]);
 
       if ((lines.size() > 1) && !lines[1].empty())
         label = boost::trim_copy(lines[1]) + "\n";
