@@ -29,10 +29,10 @@ asf_reader_c::probe_file(mm_io_c &in,
 
     unsigned char buf[4];
 
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
     if (in.read(buf, 4) != 4)
       return 0;
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
 
     if (MAGIC_ASF_WMV == get_uint32_be(buf)) {
       id_result_container_unsupported(in.get_file_name(), mtx::file_type_t::get_name(mtx::file_type_e::asf));
