@@ -64,10 +64,10 @@ avi_reader_c::probe_file(mm_io_c &in,
 
   std::string data;
   try {
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
     if (in.read(data, 12) != 12)
       return false;
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
   } catch (...) {
     return false;
   }
@@ -229,7 +229,7 @@ avi_reader_c::create_video_packetizer() {
   if (DIVX_TYPE_MPEG4 == m_divx_type)
     create_mpeg4_p2_packetizer();
 
-  else if (mtx::avc::is_avc_fourcc(codec) && !hack_engaged(ENGAGE_ALLOW_AVC_IN_VFW_MODE))
+  else if (mtx::avc::is_avc_fourcc(codec) && !mtx::hacks::is_engaged(mtx::hacks::ALLOW_AVC_IN_VFW_MODE))
     create_mpeg4_p10_packetizer();
 
   else if (mpeg1_2::is_fourcc(get_uint32_le(codec)))
@@ -390,8 +390,8 @@ avi_reader_c::create_srt_packetizer(int idx) {
 
   parser->parse();
 
-  bool is_utf8   = demuxer.m_text_io->get_byte_order() != BO_NONE;
-  demuxer.m_ptzr = add_packetizer(new textsubs_packetizer_c(this, m_ti, MKV_S_TEXTUTF8, true, is_utf8));
+  auto need_recoding = demuxer.m_text_io->get_byte_order() == BO_NONE;
+  demuxer.m_ptzr     = add_packetizer(new textsubs_packetizer_c(this, m_ti, MKV_S_TEXTUTF8, need_recoding));
 
   show_packetizer_info(id, PTZR(demuxer.m_ptzr));
 }
@@ -414,7 +414,7 @@ avi_reader_c::create_ssa_packetizer(int idx) {
   parser->parse();
 
   m_ti.m_private_data = memory_c::clone(parser->get_global());
-  demuxer.m_ptzr      = add_packetizer(new textsubs_packetizer_c(this, m_ti, parser->is_ass() ?  MKV_S_TEXTASS : MKV_S_TEXTSSA, false, false));
+  demuxer.m_ptzr      = add_packetizer(new textsubs_packetizer_c(this, m_ti, parser->is_ass() ?  MKV_S_TEXTASS : MKV_S_TEXTSSA));
 
   show_packetizer_info(id, PTZR(demuxer.m_ptzr));
 }
@@ -802,9 +802,14 @@ avi_reader_c::read(generic_packetizer_c *ptzr,
   return flush_packetizers();
 }
 
-int
+int64_t
 avi_reader_c::get_progress() {
-  return 0 == m_bytes_to_process ? 0 : 100 * m_bytes_processed / m_bytes_to_process;
+  return 0 == m_bytes_to_process ? m_in->getFilePointer() : m_bytes_processed;
+}
+
+int64_t
+avi_reader_c::get_maximum_progress() {
+  return 0 == m_bytes_to_process ? m_in->get_size() : m_bytes_to_process;
 }
 
 void
