@@ -32,7 +32,7 @@ coreaudio_reader_c::probe_file(mm_io_c &in,
     if (8 > size)
       return false;
 
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
 
     std::string magic;
     return (4 == in.read(magic, 4)) && (balg::to_lower_copy(magic) == "caff") ? 1 : 0;
@@ -114,7 +114,7 @@ coreaudio_reader_c::dump_headers()
                         )
           % m_ti.m_fname
           % m_codec_name % m_supported % m_sample_rate % m_flags % m_bytes_per_packet % m_frames_per_packet % m_channels % m_bits_per_sample
-          % (m_magic_cookie ? (boost::format("present, size %1%") % m_magic_cookie->get_size()).str() : std::string{"not present"})
+          % (m_magic_cookie ? (boost::format("present, size %1%") % m_magic_cookie->get_size()).str() : "not present"s)
           );
 
   if (m_codec.is(codec_c::type_e::A_ALAC) && m_magic_cookie && (m_magic_cookie->get_size() >= sizeof(mtx::alac::codec_config_t))) {
@@ -173,7 +173,7 @@ coreaudio_reader_c::read(generic_packetizer_c *,
     return FILE_STATUS_DONE;
 
   try {
-    m_in->setFilePointer(m_current_packet->m_position, seek_beginning);
+    m_in->setFilePointer(m_current_packet->m_position);
     auto mem = memory_c::alloc(m_current_packet->m_size);
     if (m_in->read(mem, m_current_packet->m_size) != m_current_packet->m_size)
       throw false;
