@@ -34,7 +34,7 @@ dirac_es_reader_c::probe_file(mm_io_c &in,
     if (PROBESIZE > size)
       return 0;
 
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
 
     memory_cptr buf = memory_c::alloc(READ_SIZE);
     int num_read    = in.read(buf->get_buffer(), READ_SIZE);
@@ -78,7 +78,7 @@ dirac_es_reader_c::read_headers() {
 
     parser.get_sequence_header(m_seqhdr);
 
-    m_in->setFilePointer(0, seek_beginning);
+    m_in->setFilePointer(0);
 
   } catch (...) {
     throw mtx::input::open_x();
@@ -105,7 +105,7 @@ dirac_es_reader_c::read(generic_packetizer_c *,
 
   int num_read = m_in->read(m_buffer->get_buffer(), READ_SIZE);
   if (0 < num_read)
-    PTZR0->process(new packet_t(new memory_c(m_buffer->get_buffer(), num_read)));
+    PTZR0->process(new packet_t(memory_c::borrow(m_buffer->get_buffer(), num_read)));
 
   return ((READ_SIZE != num_read) || (m_in->getFilePointer() >= m_size)) ? flush_packetizers() : FILE_STATUS_MOREDATA;
 }
