@@ -129,6 +129,7 @@ using flv_track_cptr = std::shared_ptr<flv_track_c>;
 class flv_reader_c: public generic_reader_c {
 private:
   int m_audio_track_idx, m_video_track_idx, m_selected_track_idx;
+  boost::optional<uint64_t> m_min_timestamp;
 
   flv_tag_c m_tag;
 
@@ -145,7 +146,6 @@ public:
   virtual bool new_stream_v_avc(flv_track_cptr &track, memory_cptr const &data);
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t tid);
   virtual void create_packetizers();
@@ -158,6 +158,8 @@ public:
   }
 
 protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   bool process_tag(bool skip_payload = false);
   bool process_script_tag();
   bool process_audio_tag(flv_track_cptr &track);
