@@ -54,6 +54,7 @@
 #include "common/iso639.h"
 #include "common/ivf.h"
 #include "common/kax_analyzer.h"
+#include "common/math.h"
 #include "common/mm_io.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
@@ -127,7 +128,7 @@ kax_track_t::handle_packetizer_display_dimensions() {
   // these and signal the packetizer not to extract the dimensions
   // from the bitstream.
   if ((0 != v_dwidth) && (0 != v_dheight))
-    ptzr_ptr->set_video_display_dimensions(v_dwidth, v_dheight, OPTION_SOURCE_CONTAINER);
+    ptzr_ptr->set_video_display_dimensions(v_dwidth, v_dheight, v_dunit.get_value_or(generic_packetizer_c::ddu_pixels), OPTION_SOURCE_CONTAINER);
 }
 
 void
@@ -180,6 +181,9 @@ kax_track_t::handle_packetizer_colour() {
     ptzr_ptr->set_video_projection_pose_pitch(*v_projection_pose_pitch, OPTION_SOURCE_CONTAINER);
   if (v_projection_pose_roll)
     ptzr_ptr->set_video_projection_pose_roll(*v_projection_pose_roll, OPTION_SOURCE_CONTAINER);
+
+  if (codec_id == MKV_V_UNCOMPRESSED)
+    ptzr_ptr->set_video_colour_space(v_colour_space, OPTION_SOURCE_CONTAINER);
 }
 
 void
@@ -234,7 +238,7 @@ kax_track_t::fix_display_dimension_parameters() {
   if ((0 != v_display_unit) || ((8 * v_dwidth) > v_width) || ((8 * v_dheight) > v_height))
     return;
 
-  if (boost::math::gcd(v_dwidth, v_dheight) != 1)
+  if (boost::gcd(v_dwidth, v_dheight) != 1)
     return;
 
   // max shrinking was applied, ie x264 style
@@ -278,12 +282,10 @@ kax_track_t::discard_track_statistics_tags() {
   if (!tags)
     return;
 
-  mtx::tags::remove_track_statistics(tags, track_uid);
+  mtx::tags::remove_track_statistics(tags.get(), track_uid);
 
-  if (!tags->ListSize()) {
-    delete tags;
-    tags = nullptr;
-  }
+  if (!tags->ListSize())
+    tags.reset();
 }
 
 /*
@@ -298,10 +300,10 @@ kax_reader_c::probe_file(mm_io_c &in,
   if (4 > size)
     return 0;
   try {
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
     if (in.read(data, 4) != 4)
       return 0;
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
   } catch (...) {
     return 0;
   }
@@ -367,7 +369,7 @@ kax_reader_c::unlace_vorbis_private_data(kax_track_t *t,
                                          unsigned char *buffer,
                                          int size) {
   try {
-    memory_cptr temp(new memory_c(buffer, size, false));
+    auto temp = memory_c::borrow(buffer, size);
     std::vector<memory_cptr> blocks = unlace_memory_xiph(temp);
     if (blocks.size() != 3)
       return false;
@@ -696,14 +698,6 @@ kax_reader_c::verify_dvb_subtitle_track(kax_track_t *t) {
     return false;
   }
 
-  if (t->private_data->get_size() == 4) {
-    // The subtitling type byte is missing. Add it. From ETSI EN 300 468 table 26:
-    // 0x10 = DVB subtitles (normal) with no monitor aspect ratio criticality
-
-    t->private_data->resize(5);
-    t->private_data->get_buffer()[4] = 0x10;
-  }
-
   return true;
 }
 
@@ -871,6 +865,8 @@ kax_reader_c::handle_attachments(mm_io_c *io,
   upper_lvl_el               = 0;
 
   atts->Read(*m_es, EBML_CLASS_CONTEXT(KaxAttachments), upper_lvl_el, element_found, true);
+  if (!found_in(*atts, element_found))
+    delete element_found;
 
   for (auto l1_att : *atts) {
     auto att = dynamic_cast<KaxAttached *>(l1_att);
@@ -923,10 +919,12 @@ kax_reader_c::handle_chapters(mm_io_c *io,
   if (!tmp_chapters)
     return;
 
-  EbmlElement *l2 = nullptr;
-  upper_lvl_el    = 0;
+  EbmlElement *element_found = nullptr;
+  upper_lvl_el               = 0;
 
-  tmp_chapters->Read(*m_es, EBML_CLASS_CONTEXT(KaxChapters), upper_lvl_el, l2, true);
+  tmp_chapters->Read(*m_es, EBML_CLASS_CONTEXT(KaxChapters), upper_lvl_el, element_found, true);
+  if (!found_in(*tmp_chapters, element_found))
+    delete element_found;
 
   if (m_regenerate_chapter_uids)
     mtx::chapters::regenerate_uids(*tmp_chapters);
@@ -955,10 +953,12 @@ kax_reader_c::handle_tags(mm_io_c *io,
   if (!tags)
     return;
 
-  EbmlElement *l2 = nullptr;
-  upper_lvl_el    = 0;
+  EbmlElement *element_found = nullptr;
+  upper_lvl_el               = 0;
 
-  tags->Read(*m_es, EBML_CLASS_CONTEXT(KaxTags), upper_lvl_el, l2, true);
+  tags->Read(*m_es, EBML_CLASS_CONTEXT(KaxTags), upper_lvl_el, element_found, true);
+  if (!found_in(*tags, element_found))
+    delete element_found;
 
   while (tags->ListSize() > 0) {
     if (!Is<KaxTag>((*tags)[0])) {
@@ -991,7 +991,7 @@ kax_reader_c::handle_tags(mm_io_c *io,
 
           if (contains_tag) {
             if (!track->tags)
-              track->tags = new KaxTags;
+              track->tags.reset(new KaxTags);
             track->tags->PushElement(*tag);
 
             delete_tag = false;
@@ -1036,10 +1036,12 @@ kax_reader_c::read_headers_info(mm_io_c *io,
   if (!info)
     return;
 
-  EbmlElement *l2 = nullptr;
-  upper_lvl_el    = 0;
+  EbmlElement *element_found = nullptr;
+  upper_lvl_el               = 0;
 
-  info->Read(*m_es, EBML_CLASS_CONTEXT(KaxInfo), upper_lvl_el, l2, true);
+  info->Read(*m_es, EBML_CLASS_CONTEXT(KaxInfo), upper_lvl_el, element_found, true);
+  if (!found_in(*info, element_found))
+    delete element_found;
 
   m_tc_scale          = FindChildValue<KaxTimecodeScale, uint64_t>(info, 1000000);
   m_segment_duration  = std::llround(FindChildValue<KaxDuration>(info) * m_tc_scale);
@@ -1164,12 +1166,17 @@ kax_reader_c::read_headers_track_video(kax_track_t *track,
   track->v_height       = FindChildValue<KaxVideoPixelHeight>(ktvideo);
   track->v_dwidth       = FindChildValue<KaxVideoDisplayWidth>(ktvideo,  track->v_width);
   track->v_dheight      = FindChildValue<KaxVideoDisplayHeight>(ktvideo, track->v_height);
+  track->v_dunit        = FindChildValue<KaxVideoDisplayUnit>(ktvideo,   generic_packetizer_c::ddu_pixels);
 
   track->v_pcleft       = FindChildValue<KaxVideoPixelCropLeft>(ktvideo);
   track->v_pcright      = FindChildValue<KaxVideoPixelCropRight>(ktvideo);
   track->v_pctop        = FindChildValue<KaxVideoPixelCropTop>(ktvideo);
   track->v_pcbottom     = FindChildValue<KaxVideoPixelCropBottom>(ktvideo);
 
+  auto colour_space = FindChild<KaxVideoColourSpace>(*ktvideo);
+  if (colour_space)
+    track->v_colour_space = memory_c::clone(colour_space->GetBuffer(), colour_space->GetSize());
+
   auto colour           = FindChild<KaxVideoColour>(*ktvideo);
 
   if (colour) {
@@ -1242,20 +1249,21 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
 
   int upper_lvl_el = 0;
   io->save_pos(position);
-  EbmlElement *l1 = m_es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true);
+  auto l1 = std::shared_ptr<EbmlElement>(m_es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true));
 
-  if (!l1 || !Is<KaxTracks>(l1)) {
-    delete l1;
+  if (!l1 || !Is<KaxTracks>(*l1)) {
     io->restore_pos();
 
     return;
   }
 
-  EbmlElement *l2 = nullptr;
-  upper_lvl_el    = 0;
-  l1->Read(*m_es, EBML_CLASS_CONTEXT(KaxTracks), upper_lvl_el, l2, true);
+  EbmlElement *element_found = nullptr;
+  upper_lvl_el               = 0;
+  l1->Read(*m_es, EBML_CLASS_CONTEXT(KaxTracks), upper_lvl_el, element_found, true);
+  if (!found_in(*l1, element_found))
+    delete element_found;
 
-  KaxTrackEntry *ktentry = FindChild<KaxTrackEntry>(l1);
+  KaxTrackEntry *ktentry = FindChild<KaxTrackEntry>(*l1);
   while (ktentry) {
     // We actually found a track entry :) We're happy now.
     auto track = std::make_shared<kax_track_t>();
@@ -1351,7 +1359,6 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
     ktentry = FindNextChild(static_cast<EbmlMaster &>(*l1), *ktentry);
   } // while (ktentry)
 
-  delete l1;
   io->restore_pos();
 }
 
@@ -1375,19 +1382,21 @@ kax_reader_c::handle_seek_head(mm_io_c *io,
     if (!seek_head)
       return;
 
-    EbmlElement *l2 = nullptr;
-    upper_lvl_el    = 0;
+    EbmlElement *element_found = nullptr;
+    upper_lvl_el               = 0;
 
-    seek_head->Read(*m_es, EBML_CLASS_CONTEXT(KaxSeekHead), upper_lvl_el, l2, true);
+    seek_head->Read(*m_es, EBML_CLASS_CONTEXT(KaxSeekHead), upper_lvl_el, element_found, true);
+    if (!found_in(*seek_head, element_found))
+      delete element_found;
 
     for (auto l2 : *seek_head) {
       if (!Is<KaxSeek>(l2))
         continue;
 
-      KaxSeek &seek = *static_cast<KaxSeek *>(l2);
-      int64_t pos   = FindChildValue<KaxSeekPosition, int64_t>(seek, -1);
+      auto &seek        = *static_cast<KaxSeek *>(l2);
+      auto new_seek_pos = FindChildValue<KaxSeekPosition, int64_t>(seek, -1);
 
-      if (-1 == pos)
+      if (-1 == new_seek_pos)
         continue;
 
       auto *k_id = FindChild<KaxSeekID>(seek);
@@ -1407,20 +1416,20 @@ kax_reader_c::handle_seek_head(mm_io_c *io,
       if (dl1t_unknown == type)
         continue;
 
-      pos = static_cast<KaxSegment *>(l0)->GetGlobalPosition(pos);
+      new_seek_pos = static_cast<KaxSegment *>(l0)->GetGlobalPosition(new_seek_pos);
 
       if (dl1t_seek_head == type)
-        next_seek_head_positions.push_back(pos);
+        next_seek_head_positions.push_back(new_seek_pos);
       else
-        m_deferred_l1_positions[type].push_back(pos);
+        m_deferred_l1_positions[type].push_back(new_seek_pos);
     }
 
   } catch (...) {
     return;
   }
 
-  for (auto pos : next_seek_head_positions)
-    handle_seek_head(io, l0, pos);
+  for (auto new_seek_head_pos : next_seek_head_positions)
+    handle_seek_head(io, l0, new_seek_head_pos);
 }
 
 void
@@ -1477,7 +1486,7 @@ kax_reader_c::read_deferred_level1_elements(KaxSegment &segment) {
   for (auto position : m_deferred_l1_positions[dl1t_tags])
     handle_tags(m_in.get(), &segment, position);
 
-  if (!hack_engaged(ENGAGE_KEEP_TRACK_STATISTICS_TAGS))
+  if (!mtx::hacks::is_engaged(mtx::hacks::KEEP_TRACK_STATISTICS_TAGS))
     discard_track_statistics_tags();
 
   if (!m_ti.m_no_global_tags)
@@ -1496,7 +1505,7 @@ kax_reader_c::read_headers_internal() {
     m_in_file->enable_reporting(!g_identifying);
 
     // Find the EbmlHead element. Must be the first one.
-    EbmlElement *l0 = m_es->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFFFFFFFFFLL);
+    auto l0 = std::shared_ptr<EbmlElement>(m_es->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFFFFFFFFFLL));
     if (!l0) {
       mxwarn(Y("matroska_reader: no EBML head found.\n"));
       return false;
@@ -1504,17 +1513,15 @@ kax_reader_c::read_headers_internal() {
 
     // Don't verify its data for now.
     l0->SkipData(*m_es, EBML_CONTEXT(l0));
-    delete l0;
 
     // Next element must be a segment
-    l0 = m_es->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
-    std::shared_ptr<EbmlElement> l0_cptr(l0);
+    l0.reset(m_es->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL));
     if (!l0) {
       if (verbose)
         mxwarn(Y("matroska_reader: No segment found.\n"));
       return false;
     }
-    if (!Is<KaxSegment>(l0)) {
+    if (!Is<KaxSegment>(*l0)) {
       if (verbose)
         mxwarn(Y("matroska_reader: No segment found.\n"));
       return false;
@@ -1526,7 +1533,7 @@ kax_reader_c::read_headers_internal() {
     m_tc_scale = TIMESTAMP_SCALE;
 
     while (m_in->getFilePointer() < m_in_file->get_segment_end()) {
-      auto l1 = ebml_element_cptr{ m_in_file->read_next_level1_element() };
+      auto l1 = m_in_file->read_next_level1_element();
       if (!l1)
         break;
 
@@ -1546,7 +1553,7 @@ kax_reader_c::read_headers_internal() {
         m_deferred_l1_positions[dl1t_tags].push_back(l1->GetElementPosition());
 
       else if (Is<KaxSeekHead>(*l1))
-        handle_seek_head(m_in.get(), l0, l1->GetElementPosition());
+        handle_seek_head(m_in.get(), l0.get(), l1->GetElementPosition());
 
       else if (Is<KaxCluster>(*l1))
         cluster = std::static_pointer_cast<KaxCluster>(l1);
@@ -1576,11 +1583,11 @@ kax_reader_c::read_headers_internal() {
   }
 
   auto cluster_pos = cluster ? cluster->GetElementPosition() : m_in->get_size();
-  m_in->setFilePointer(cluster_pos, seek_beginning);
+  m_in->setFilePointer(cluster_pos);
 
   verify_tracks();
 
-  m_in->setFilePointer(cluster_pos, seek_beginning);
+  m_in->setFilePointer(cluster_pos);
 
   return true;
 }
@@ -1591,7 +1598,7 @@ kax_reader_c::process_global_tags() {
     return;
 
   for (auto tag : *m_tags)
-    add_tags(static_cast<KaxTag *>(tag));
+    add_tags(static_cast<KaxTag &>(*tag));
 
   m_tags->RemoveAll();
 }
@@ -1669,7 +1676,7 @@ kax_reader_c::set_packetizer_headers(kax_track_t *t) {
 void
 kax_reader_c::create_video_packetizer(kax_track_t *t,
                                       track_info_c &nti) {
-  if (t->codec.is(codec_c::type_e::V_MPEG4_P10) && t->ms_compat && !hack_engaged(ENGAGE_ALLOW_AVC_IN_VFW_MODE))
+  if (t->codec.is(codec_c::type_e::V_MPEG4_P10) && t->ms_compat && !mtx::hacks::is_engaged(mtx::hacks::ALLOW_AVC_IN_VFW_MODE))
     create_avc_es_video_packetizer(t, nti);
 
   else if (t->codec.is(codec_c::type_e::V_MPEG12)) {
@@ -1963,6 +1970,22 @@ kax_reader_c::create_audio_packetizer(kax_track_t *t,
   t->handle_packetizer_codec_delay();
 }
 
+void
+kax_reader_c::create_dvbsub_subtitle_packetizer(kax_track_t &t,
+                                                track_info_c &nti) {
+  if (t.private_data->get_size() == 4) {
+    // The subtitling type byte is missing. Add it. From ETSI EN 300 468 table 26:
+    // 0x10 = DVB subtitles (normal) with no monitor aspect ratio criticality
+
+    t.private_data->resize(5);
+    t.private_data->get_buffer()[4] = 0x10;
+  }
+
+  set_track_packetizer(&t, new dvbsub_packetizer_c(this, nti, t.private_data));
+  show_packetizer_info(t.tnum, t.ptzr_ptr);
+  t.sub_type = 'p';
+}
+
 void
 kax_reader_c::create_subtitle_packetizer(kax_track_t *t,
                                          track_info_c &nti) {
@@ -1972,21 +1995,20 @@ kax_reader_c::create_subtitle_packetizer(kax_track_t *t,
 
     t->sub_type = 'v';
 
-  } else if (t->codec.is(codec_c::type_e::S_DVBSUB)) {
-    set_track_packetizer(t, new dvbsub_packetizer_c(this, nti, t->private_data));
-    show_packetizer_info(t->tnum, t->ptzr_ptr);
-    t->sub_type = 'p';
+  } else if (t->codec.is(codec_c::type_e::S_DVBSUB))
+    create_dvbsub_subtitle_packetizer(*t, nti);
 
-  } else if (t->codec.is(codec_c::type_e::S_WEBVTT)) {
+  else if (t->codec.is(codec_c::type_e::S_WEBVTT)) {
     set_track_packetizer(t, new webvtt_packetizer_c(this, nti));
     show_packetizer_info(t->tnum, t->ptzr_ptr);
 
     t->sub_type = 't';
 
   } else if (balg::starts_with(t->codec_id, "S_TEXT") || (t->codec_id == "S_SSA") || (t->codec_id == "S_ASS")) {
-    std::string new_codec_id = ((t->codec_id == "S_SSA") || (t->codec_id == "S_ASS")) ? std::string("S_TEXT/") + std::string(&t->codec_id[2]) : t->codec_id;
+    std::string new_codec_id = ((t->codec_id == "S_SSA") || (t->codec_id == "S_ASS")) ? "S_TEXT/"s + std::string(&t->codec_id[2]) : t->codec_id;
 
-    set_track_packetizer(t, new textsubs_packetizer_c(this, nti, new_codec_id.c_str(), false, true));
+    auto recoding_requested = mtx::includes(m_ti.m_sub_charsets, t->tnum) || mtx::includes(m_ti.m_sub_charsets, t->tnum);
+    set_track_packetizer(t, new textsubs_packetizer_c(this, nti, new_codec_id.c_str(), recoding_requested));
     show_packetizer_info(t->tnum, t->ptzr_ptr);
 
     t->sub_type = 't';
@@ -2044,7 +2066,7 @@ kax_reader_c::create_packetizer(int64_t tid) {
   if (t->tags && demuxing_requested('T', t->tnum))
     nti.m_tags       = clone(t->tags);
 
-  if (hack_engaged(ENGAGE_FORCE_PASSTHROUGH_PACKETIZER)) {
+  if (mtx::hacks::is_engaged(mtx::hacks::FORCE_PASSTHROUGH_PACKETIZER)) {
     init_passthrough_packetizer(t, nti);
     set_packetizer_headers(t);
 
@@ -2130,7 +2152,7 @@ kax_reader_c::create_vc1_video_packetizer(kax_track_t *t,
   show_packetizer_info(t->tnum, t->ptzr_ptr);
 
   if (t->private_data && (sizeof(alBITMAPINFOHEADER) < t->private_data->get_size()))
-    t->ptzr_ptr->process(new packet_t(new memory_c(t->private_data->get_buffer() + sizeof(alBITMAPINFOHEADER), t->private_data->get_size() - sizeof(alBITMAPINFOHEADER), false)));
+    t->ptzr_ptr->process(new packet_t(memory_c::borrow(t->private_data->get_buffer() + sizeof(alBITMAPINFOHEADER), t->private_data->get_size() - sizeof(alBITMAPINFOHEADER))));
 }
 
 void
@@ -2143,7 +2165,7 @@ kax_reader_c::read_first_frames(kax_track_t *t,
 
   try {
     while (true) {
-      auto cluster = std::unique_ptr<KaxCluster>{m_in_file->read_next_cluster()};
+      auto cluster = m_in_file->read_next_cluster();
       if (!cluster)
         return;
 
@@ -2169,9 +2191,9 @@ kax_reader_c::read_first_frames(kax_track_t *t,
               continue;
 
             DataBuffer &data_buffer = block_simple->GetBuffer(frame_idx);
-            block_track->first_frames_data.push_back(memory_cptr(new memory_c(data_buffer.Buffer(), data_buffer.Size())));
+            block_track->first_frames_data.push_back(memory_c::borrow(data_buffer.Buffer(), data_buffer.Size()));
             block_track->content_decoder.reverse(block_track->first_frames_data.back(), CONTENT_ENCODING_SCOPE_BLOCK);
-            block_track->first_frames_data.back()->grab();
+            block_track->first_frames_data.back()->take_ownership();
           }
 
         } else if (Is<KaxBlockGroup>((*cluster)[bgidx])) {
@@ -2194,9 +2216,9 @@ kax_reader_c::read_first_frames(kax_track_t *t,
               continue;
 
             DataBuffer &data_buffer = block->GetBuffer(frame_idx);
-            block_track->first_frames_data.push_back(memory_cptr(new memory_c(data_buffer.Buffer(), data_buffer.Size())));
+            block_track->first_frames_data.push_back(memory_cptr(memory_c::borrow(data_buffer.Buffer(), data_buffer.Size())));
             block_track->content_decoder.reverse(block_track->first_frames_data.back(), CONTENT_ENCODING_SCOPE_BLOCK);
-            block_track->first_frames_data.back()->grab();
+            block_track->first_frames_data.back()->take_ownership();
           }
         }
       }
@@ -2220,20 +2242,16 @@ kax_reader_c::read(generic_packetizer_c *requested_ptzr,
     auto requested_ptzr_track = m_ptzr_to_track_map[requested_ptzr];
     if (   !requested_ptzr_track
         || (!force && ('a' != requested_ptzr_track->type) && ('v' != requested_ptzr_track->type))
-        || ( force && (128 * 1024 * 1024 >= num_queued_bytes)))
+        || (128 * 1024 * 1024 < num_queued_bytes))
       return FILE_STATUS_HOLDING;
   }
 
   try {
-    KaxCluster *cluster = m_in_file->read_next_cluster();
-    if (!cluster) {
-      flush_packetizers();
+    auto cluster = m_in_file->read_next_cluster();
+    if (!cluster)
+      return finish_file();
 
-      m_file_status = FILE_STATUS_DONE;
-      return FILE_STATUS_DONE;
-    }
-
-    auto cluster_ts = FindChildValue<KaxClusterTimecode>(cluster);
+    auto cluster_ts = FindChildValue<KaxClusterTimecode>(*cluster);
     cluster->InitTimecode(cluster_ts, m_tc_scale);
 
     if (-1 == m_first_timestamp) {
@@ -2250,25 +2268,32 @@ kax_reader_c::read(generic_packetizer_c *requested_ptzr,
       EbmlElement *element = (*cluster)[bgidx];
 
       if (Is<KaxSimpleBlock>(element))
-        process_simple_block(cluster, static_cast<KaxSimpleBlock *>(element));
+        process_simple_block(cluster.get(), static_cast<KaxSimpleBlock *>(element));
 
       else if (Is<KaxBlockGroup>(element))
-        process_block_group(cluster, static_cast<KaxBlockGroup *>(element));
+        process_block_group(cluster.get(), static_cast<KaxBlockGroup *>(element));
     }
 
-    delete cluster;
-
   } catch (...) {
     mxwarn(boost::format("%1% %2% %3%\n")
            % (boost::format(Y("%1%: an unknown exception occurred.")) % "kax_reader_c::read()")
            % Y("This usually indicates a damaged file structure.") % Y("The file will not be processed further."));
-    flush_packetizers();
-    return FILE_STATUS_DONE;
+    return finish_file();
   }
 
   return FILE_STATUS_MOREDATA;
 }
 
+file_status_e
+kax_reader_c::finish_file() {
+  flush_packetizers();
+
+  m_in->setFilePointer(0, seek_end);
+  m_file_status = FILE_STATUS_DONE;
+
+  return FILE_STATUS_DONE;
+}
+
 void
 kax_reader_c::process_simple_block(KaxCluster *cluster,
                                    KaxSimpleBlock *block_simple) {
@@ -2326,7 +2351,7 @@ kax_reader_c::process_simple_block(KaxCluster *cluster,
     size_t i;
     for (i = 0; block_simple->NumberFrames() > i; ++i) {
       DataBuffer &data_buffer = block_simple->GetBuffer(i);
-      memory_cptr data(new memory_c(data_buffer.Buffer(), data_buffer.Size(), false));
+      auto data = memory_c::borrow(data_buffer.Buffer(), data_buffer.Size());
       block_track->content_decoder.reverse(data, CONTENT_ENCODING_SCOPE_BLOCK);
 
       packet_cptr packet(new packet_t(data, m_last_timestamp + i * frame_duration, block_duration, block_bref, block_fref));
@@ -2340,7 +2365,7 @@ kax_reader_c::process_simple_block(KaxCluster *cluster,
     size_t i;
     for (i = 0; i < block_simple->NumberFrames(); i++) {
       DataBuffer &data_buffer = block_simple->GetBuffer(i);
-      memory_cptr data(new memory_c(data_buffer.Buffer(), data_buffer.Size(), false));
+      auto data = memory_c::borrow(data_buffer.Buffer(), data_buffer.Size());
       block_track->content_decoder.reverse(data, CONTENT_ENCODING_SCOPE_BLOCK);
 
       if (('s' == block_track->type) && ('t' == block_track->sub_type)) {
@@ -2388,7 +2413,7 @@ kax_reader_c::process_block_group_common(KaxBlockGroup *block_group,
 
     auto blockmore     = static_cast<KaxBlockMore *>(child);
     auto blockadd_data = &GetChild<KaxBlockAdditional>(*blockmore);
-    auto blockadded    = std::make_shared<memory_c>(blockadd_data->GetBuffer(), blockadd_data->GetSize(), false);
+    auto blockadded    = memory_c::borrow(blockadd_data->GetBuffer(), blockadd_data->GetSize());
     block_track.content_decoder.reverse(blockadded, CONTENT_ENCODING_SCOPE_BLOCK);
 
     packet->data_adds.push_back(blockadded);
@@ -2470,7 +2495,7 @@ kax_reader_c::process_block_group(KaxCluster *cluster,
     size_t i;
     for (i = 0; i < block->NumberFrames(); i++) {
       auto &data_buffer = block->GetBuffer(i);
-      auto data         = std::make_shared<memory_c>(data_buffer.Buffer(), data_buffer.Size(), false);
+      auto data         = memory_c::borrow(data_buffer.Buffer(), data_buffer.Size());
       block_track->content_decoder.reverse(data, CONTENT_ENCODING_SCOPE_BLOCK);
 
       auto packet                = std::make_shared<packet_t>(data, m_last_timestamp + i * frame_duration, block_duration, block_bref, block_fref);
@@ -2491,7 +2516,7 @@ kax_reader_c::process_block_group(KaxCluster *cluster,
 
   for (auto block_idx = 0u, num_frames = block->NumberFrames(); block_idx < num_frames; ++block_idx) {
     auto &data_buffer = block->GetBuffer(block_idx);
-    auto data         = std::make_shared<memory_c>(data_buffer.Buffer(), data_buffer.Size(), false);
+    auto data         = memory_c::borrow(data_buffer.Buffer(), data_buffer.Size());
     block_track->content_decoder.reverse(data, CONTENT_ENCODING_SCOPE_BLOCK);
 
     if (('s' == block_track->type) && ('t' == block_track->sub_type)) {
@@ -2519,14 +2544,6 @@ kax_reader_c::process_block_group(KaxCluster *cluster,
   block_track->units_processed    += block->NumberFrames();
 }
 
-int
-kax_reader_c::get_progress() {
-  if (0 != m_segment_duration)
-    return std::min(m_last_timestamp, m_segment_duration) * 100 / m_segment_duration;
-
-  return 100 * m_in->getFilePointer() / m_size;
-}
-
 void
 kax_reader_c::set_headers() {
   generic_reader_c::set_headers();
@@ -2555,7 +2572,7 @@ kax_reader_c::determine_minimum_timestamps() {
 
   while (true) {
     try {
-      auto cluster = std::shared_ptr<KaxCluster>(m_in_file->read_next_cluster());
+      auto cluster = m_in_file->read_next_cluster();
       if (!cluster)
         return;
 
@@ -2684,6 +2701,9 @@ kax_reader_c::identify() {
     if ((0 != track->v_dwidth) && (0 != track->v_dheight))
       info.add(mtx::id::display_dimensions, boost::format("%1%x%2%") % track->v_dwidth % track->v_dheight);
 
+    if (track->v_dunit)
+      info.set(mtx::id::display_unit, *track->v_dunit);
+
     if ((0 != track->v_pcleft) || (0 != track->v_pctop) || (0 != track->v_pcright) || (0 != track->v_pcbottom))
       info.add(mtx::id::cropping, boost::format("%1%,%2%,%3%,%4%") % track->v_pcleft % track->v_pctop % track->v_pcright % track->v_pcbottom);
 
