@@ -19,7 +19,6 @@
 #include "common/endian.h"
 #include "common/error.h"
 #include "common/id_info.h"
-#include "common/math.h"
 #include "common/mp3.h"
 #include "common/mpeg1_2.h"
 #include "common/mpeg4_p2.h"
@@ -43,14 +42,14 @@ mpeg_ps_reader_c::probe_file(mm_io_c &in,
   try {
     unsigned char buf[4];
 
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
     if (in.read(buf, 4) != 4)
       return 0;
 
     if (get_uint32_be(buf) == MPEGVIDEO_PACKET_START_CODE)
       return 1;
 
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
 
     auto mem      = memory_c::alloc(32 * 1024);
     auto num_read = in.read(mem, mem->get_size());
@@ -190,7 +189,7 @@ mpeg_ps_reader_c::read_headers() {
   sort_tracks();
   calculate_global_timestamp_offset();
 
-  m_in->setFilePointer(0, seek_beginning);
+  m_in->setFilePointer(0);
 
   if (verbose) {
     show_demuxer_info();
@@ -222,7 +221,7 @@ mpeg_ps_reader_c::sort_tracks() {
   if (!m_debug_headers)
     return;
 
-  auto info = std::string{"mpeg_ps: Supported streams, sorted by ID: "};
+  auto info = "mpeg_ps: Supported streams, sorted by ID: "s;
   for (i = 0; tracks.size() > i; ++i)
     info += (boost::format("0x%|1$02x|(0x%|2$02x|) ") % tracks[i]->id.id % tracks[i]->id.sub_id).str();
 
@@ -977,7 +976,7 @@ mpeg_ps_reader_c::found_new_stream(mpeg_ps_id_t id) {
     mxdebug_if(m_debug_timestamps && packet.has_pts(),
                boost::format("Timestamp for track %1%: %2% [%3%] (DTS: %4%)\n")
                % id % format_timestamp(packet.pts()) % (packet.pts() * 90 / 1000000ll)
-               % (packet.has_dts() ? (boost::format("%1% [%2%]") % format_timestamp(packet.dts()) % (packet.dts() * 90 / 1000000ll)).str() : std::string{"none"}));
+               % (packet.has_dts() ? (boost::format("%1% [%2%]") % format_timestamp(packet.dts()) % (packet.dts() * 90 / 1000000ll)).str() : "none"s));
 
     if (mtx::includes(blacklisted_ids, id.idx()))
       return;
@@ -1355,7 +1354,7 @@ mpeg_ps_reader_c::read(generic_packetizer_c *requested_ptzr,
 
       if (0 < track->buffer_size) {
         if (((track->buffer_usage + packet.m_length) > track->buffer_size)) {
-          packet_t *new_packet = new packet_t(new memory_c(track->buffer, track->buffer_usage, false));
+          auto new_packet = std::make_shared<packet_t>(memory_c::borrow(track->buffer, track->buffer_usage));
 
           if (!track->multiple_timestamps_packet_extension->empty()) {
             new_packet->extensions.push_back(packet_extension_cptr(track->multiple_timestamps_packet_extension));
