@@ -25,7 +25,6 @@
 #include "common/endian.h"
 #include "common/file.h"
 #include "common/hdmv_textst.h"
-#include "common/math.h"
 #include "common/mp3.h"
 #include "common/mm_file_io.h"
 #include "common/mm_mpls_multi_file_io.h"
@@ -113,7 +112,7 @@ track_c::track_c(reader_c &p_reader,
   , skip_packet_data_bytes{}
   , m_debug_delivery{}
   , m_debug_timestamp_wrapping{}
-  , m_debug_headers{"mpeg_ts|headers"}
+  , m_debug_headers{"mpeg_ts|mpeg_ts_headers"}
 {
 }
 
@@ -131,7 +130,7 @@ track_c::send_to_packetizer() {
                           : m_apply_dts_timestamp_fix && (m_previous_timestamp == m_timestamp) ? timestamp_c{}
                           :                                                                      std::max(m_timestamp, f.m_global_timestamp_offset);
 
-  auto timestamp_to_check = timestamp_to_use.valid() ? timestamp_to_use : f.m_stream_timestamp;
+  auto timestamp_to_check = f.m_stream_timestamp.valid() ? f.m_stream_timestamp : timestamp_c::ns(0);
   auto const &min         = f.m_timestamp_restriction_min;
   auto const &max         = f.m_timestamp_restriction_max;
   auto use_packet         = ptzr != -1;
@@ -140,13 +139,11 @@ track_c::send_to_packetizer() {
       || (max.valid() && (timestamp_to_check > max)))
     use_packet = false;
 
-  if (timestamp_to_use.valid()) {
-    f.m_stream_timestamp  = timestamp_to_use;
-    timestamp_to_use     -= std::max(f.m_global_timestamp_offset, min.valid() ? min : timestamp_c::ns(0));
-  }
+  if (timestamp_to_use.valid() && f.m_global_timestamp_offset.valid())
+    timestamp_to_use -= std::min(timestamp_to_use, f.m_global_timestamp_offset);
 
-  mxdebug_if(m_debug_delivery, boost::format("send_to_packetizer: PID %1% expected %2% actual %3% timestamp_to_use %4% m_previous_timestamp %5%\n")
-             % pid % pes_payload_size_to_read % pes_payload_read->get_size() % timestamp_to_use % m_previous_timestamp);
+  mxdebug_if(m_debug_delivery, boost::format("send_to_packetizer: PID %1% expected %2% actual %3% timestamp_to_use %4% m_previous_timestamp %5% stream_timestamp %6% restriction %7%/%8% use? %9%\n")
+             % pid % pes_payload_size_to_read % pes_payload_read->get_size() % timestamp_to_use % m_previous_timestamp % f.m_stream_timestamp % min % max % use_packet);
 
   if (use_packet) {
     auto bytes_to_skip = std::min<size_t>(pes_payload_read->get_size(), skip_packet_data_bytes);
@@ -528,11 +525,11 @@ track_c::set_pid(uint16_t new_pid) {
 
   std::string arg;
   m_debug_delivery = debugging_c::requested("mpeg_ts")
-                  || (   debugging_c::requested("delivery", &arg)
+                  || (   debugging_c::requested("mpeg_ts_delivery", &arg)
                       && (arg.empty() || (arg == to_string(pid))));
 
   m_debug_timestamp_wrapping = debugging_c::requested("mpeg_ts")
-                            || (   debugging_c::requested("timestamp_wrapping", &arg)
+                            || (   debugging_c::requested("mpeg_ts_timestamp_wrapping", &arg)
                                 && (arg.empty() || (arg == to_string(pid))));
 }
 
@@ -1020,7 +1017,7 @@ reader_c::detect_packet_size(mm_io_c &in,
 
     mxdebug_if(debug, boost::format("detect_packet_size: size to probe %1% num required startcodes %2%\n") % size % num_startcodes_required);
 
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
     size = in.read(mem, size);
 
     std::vector<int> positions;
@@ -1057,15 +1054,15 @@ reader_c::reader_c(const track_info_c &ti,
                    const mm_io_cptr &in)
   : generic_reader_c(ti, in)
   , m_current_file{}
-  , m_dont_use_audio_pts{      "mpeg_ts|dont_use_audio_pts"}
-  , m_debug_resync{            "mpeg_ts|resync"}
-  , m_debug_pat_pmt{           "mpeg_ts|pat|pmt|headers"}
-  , m_debug_sdt{               "mpeg_ts|sdt|headers"}
-  , m_debug_headers{           "mpeg_ts|headers"}
-  , m_debug_pes_headers{       "mpeg_ts|headers|pes_headers"}
-  , m_debug_packet{            "mpeg_ts|packet"}
-  , m_debug_aac{               "mpeg_ts|mpeg_aac"}
-  , m_debug_timestamp_wrapping{"mpeg_ts|timestamp_wrapping"}
+  , m_dont_use_audio_pts{      "mpeg_ts|mpeg_ts_dont_use_audio_pts"}
+  , m_debug_resync{            "mpeg_ts|mpeg_ts_resync"}
+  , m_debug_pat_pmt{           "mpeg_ts|mpeg_ts_pat|mpeg_ts_headers|mpeg_ts_pmt"}
+  , m_debug_sdt{               "mpeg_ts|mpeg_ts_sdt|mpeg_ts_headers"}
+  , m_debug_headers{           "mpeg_ts|mpeg_ts_headers"}
+  , m_debug_pes_headers{       "mpeg_ts|mpeg_ts_headers|mpeg_ts_pes_headers"}
+  , m_debug_packet{            "mpeg_ts|mpeg_ts_packet"}
+  , m_debug_aac{               "mpeg_ts|mpeg_ts_aac"}
+  , m_debug_timestamp_wrapping{"mpeg_ts|mpeg_ts_timestamp_wrapping"}
   , m_debug_clpi{              "mpeg_ts|mpeg_ts_clpi|clpi"}
   , m_debug_mpls{              "mpeg_ts|mpeg_ts_mpls|mpls"}
 {
@@ -1101,6 +1098,7 @@ reader_c::read_headers_for_file(std::size_t file_num) {
 
   try {
     auto file_size           = f.m_in->get_size();
+    m_bytes_to_process      += file_size;
     f.m_probe_range          = calculate_probe_range(file_size, 10 * 1024 * 1024);
     auto size_to_probe       = std::min<uint64_t>(file_size,     f.m_probe_range);
     auto min_size_to_probe   = std::min<uint64_t>(size_to_probe, 5 * 1024 * 1024);
@@ -1163,7 +1161,7 @@ reader_c::read_headers_for_file(std::size_t file_num) {
 
   mxdebug_if(m_debug_headers, boost::format("read_headers: Detection done on %1% bytes\n") % f.m_in->getFilePointer());
 
-  f.m_in->setFilePointer(0, seek_beginning); // rewind file for later remux
+  f.m_in->setFilePointer(0); // rewind file for later remux
 
   // Run probe_packet_complete() for track-type detection once for
   // each track. This way tracks that don't actually need their
@@ -1268,6 +1266,10 @@ reader_c::determine_global_timestamp_offset() {
   f.m_in->clear_eof();
 
   reset_processing_state(processing_state_e::muxing);
+
+  if (debugging_c::requested("mpeg_ts_dont_offset_timestamps"))
+    for (auto const &file : m_files)
+      file->m_global_timestamp_offset = timestamp_c::ns(0);
 }
 
 void
@@ -1885,6 +1887,7 @@ reader_c::parse_pes(track_c &track) {
 
   if (pts.valid()) {
     track.m_previous_valid_timestamp = pts;
+    f.m_stream_timestamp             = pts;
 
     if (   mtx::included_in(track.type, pid_type_e::audio, pid_type_e::video)
         && (   !f.m_global_timestamp_offset.valid()
@@ -2019,7 +2022,7 @@ reader_c::handle_transport_errors(track_c &track,
                % track.pid
                % file().m_position
                % (ts_header.has_transport_error() ? "transport_error flag" : "wrong continuity_counter")
-               % (track.m_expected_next_continuity_counter ? to_string(static_cast<unsigned int>(track.m_expected_next_continuity_counter.get())) : std::string{"—"})
+               % (track.m_expected_next_continuity_counter ? to_string(static_cast<unsigned int>(track.m_expected_next_continuity_counter.get())) : "—"s)
                % static_cast<unsigned int>(ts_header.continuity_counter())
                % track.pes_payload_size_to_read
                % track.pes_payload_read->get_size()
@@ -2341,9 +2344,10 @@ reader_c::create_hdmv_textst_subtitles_packetizer(track_ptr const &track) {
 
 void
 reader_c::create_srt_subtitles_packetizer(track_ptr const &track) {
-  track->ptzr = add_packetizer(new textsubs_packetizer_c(this, m_ti, MKV_S_TEXTUTF8, false, true));
+  auto recoding_requested = mtx::includes(m_ti.m_sub_charsets, track->m_id) || mtx::includes(m_ti.m_sub_charsets, track->m_id);
+  track->ptzr             = add_packetizer(new textsubs_packetizer_c(this, m_ti, MKV_S_TEXTUTF8, recoding_requested));
 
-  auto &converter = dynamic_cast<teletext_to_srt_packet_converter_c &>(*track->converter);
+  auto &converter         = dynamic_cast<teletext_to_srt_packet_converter_c &>(*track->converter);
 
   converter.demux_page(*track->m_ttx_wanted_page, PTZR(track->ptzr));
   converter.override_encoding(*track->m_ttx_wanted_page, track->language);
@@ -2381,8 +2385,10 @@ reader_c::all_files_done()
 
 file_status_e
 reader_c::finish() {
-  if (all_files_done())
+  if (all_files_done()) {
+    m_bytes_processed = m_bytes_to_process;
     return flush_packetizers();
+  }
 
   for (auto &track : m_tracks) {
     if (track->m_file_num != m_current_file)
@@ -2425,6 +2431,7 @@ reader_c::read(generic_packetizer_c *requested_ptzr,
   }
 
   f.m_packet_sent_to_packetizer = false;
+  auto prior_position           = f.m_in->getFilePointer();
 
   unsigned char buf[TS_MAX_PACKET_SIZE + 1];
 
@@ -2445,6 +2452,8 @@ reader_c::read(generic_packetizer_c *requested_ptzr,
     parse_packet(buf);
   }
 
+  m_bytes_processed += f.m_in->getFilePointer() - prior_position;
+
   return FILE_STATUS_MOREDATA;
 }
 
@@ -2651,4 +2660,14 @@ reader_c::add_external_files_from_mpls(mm_mpls_multi_file_io_c &mpls_in) {
   }
 }
 
+int64_t
+reader_c::get_progress() {
+  return m_bytes_processed;
+}
+
+int64_t
+reader_c::get_maximum_progress() {
+  return m_bytes_to_process;
+}
+
 }}
