@@ -328,7 +328,7 @@ public:
   mtx::bytes::buffer_cptr m_probe_data;
   mtx::avc::es_parser_cptr m_avc_parser;
   mtx::hevc::es_parser_cptr m_hevc_parser;
-  truehd_parser_cptr m_truehd_parser;
+  mtx::truehd::parser_cptr m_truehd_parser;
   std::shared_ptr<M2VParser> m_m2v_parser;
   mtx::vc1::es_parser_cptr m_vc1_parser;
 
@@ -422,13 +422,15 @@ using file_cptr = std::shared_ptr<file_t>;
 class reader_c: public generic_reader_c {
 protected:
   std::vector<file_cptr> m_files;
-  std::size_t m_current_file;
+  std::size_t m_current_file, m_packet_num{};
 
   std::vector<track_ptr> m_tracks, m_all_probed_tracks;
   std::map<generic_packetizer_c *, track_ptr> m_ptzr_to_track_map;
 
   std::vector<timestamp_c> m_chapter_timestamps;
 
+  int64_t m_bytes_to_process{}, m_bytes_processed{};
+
   debugging_option_c m_dont_use_audio_pts, m_debug_resync, m_debug_pat_pmt, m_debug_sdt, m_debug_headers, m_debug_pes_headers, m_debug_packet, m_debug_aac, m_debug_timestamp_wrapping, m_debug_clpi, m_debug_mpls;
 
 protected:
@@ -445,7 +447,6 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *requested_ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t tid);
   virtual void create_packetizers();
@@ -453,10 +454,15 @@ public:
 
   virtual void parse_packet(unsigned char *buf);
 
+  virtual int64_t get_progress() override;
+  virtual int64_t get_maximum_progress() override;
+
   static timestamp_c read_timestamp(unsigned char *p);
   static int detect_packet_size(mm_io_c &in, uint64_t size);
 
 private:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   void read_headers_for_file(std::size_t file_num);
 
   track_ptr find_track_for_pid(uint16_t pid) const;
