@@ -55,7 +55,7 @@
 #define BUFFER_SIZE 4096
 
 struct ogm_frame_t {
-  memory_c *mem;
+  memory_cptr mem;
   int64_t duration;
   unsigned char flags;
 };
@@ -123,7 +123,7 @@ public:
 
 class ogm_a_opus_demuxer_c: public ogm_demuxer_c {
 protected:
-  timestamp_c m_calculated_end_timestamp;
+  timestamp_c m_previous_page_end_timestamp, m_timestamp_shift;
 
   static debugging_option_c ms_debug;
 
@@ -149,7 +149,7 @@ public:
   };
 };
 
-debugging_option_c ogm_a_opus_demuxer_c::ms_debug{"opus"};
+debugging_option_c ogm_a_opus_demuxer_c::ms_debug{"opus|opus_reader|ogm_opus_reader"};
 
 class ogm_a_vorbis_demuxer_c: public ogm_demuxer_c {
 public:
@@ -287,12 +287,10 @@ extract_vorbis_comments(const memory_cptr &mem) {
 
     for (i = 0; i < n; i++) {
       len = in.read_uint32_le();
-      memory_cptr buffer(new memory_c((unsigned char *)safemalloc(len + 1), len + 1));
+      comments->emplace_back(' ', len);
 
-      if (in.read(buffer->get_buffer(), len) != len)
+      if (in.read(comments->back(), len) != len)
         throw false;
-
-      comments->push_back(std::string((char *)buffer->get_buffer(), len));
     }
   } catch(...) {
   }
@@ -311,10 +309,10 @@ ogm_reader_c::probe_file(mm_io_c &in,
   if (4 > size)
     return 0;
   try {
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
     if (in.read(data, 4) != 4)
       return 0;
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
   } catch (...) {
     return 0;
   }
@@ -529,7 +527,7 @@ ogm_reader_c::handle_new_stream(ogg_page *og) {
     if (!strncmp(sth->streamtype, "video", 5)) {
       memcpy(buf, (char *)sth->subtype, 4);
 
-      if (mtx::avc::is_avc_fourcc(buf) && !hack_engaged(ENGAGE_ALLOW_AVC_IN_VFW_MODE))
+      if (mtx::avc::is_avc_fourcc(buf) && !mtx::hacks::is_engaged(mtx::hacks::ALLOW_AVC_IN_VFW_MODE))
         dmx = new ogm_v_avc_demuxer_c(this);
       else
         dmx = new ogm_v_mscomp_demuxer_c(this);
@@ -670,7 +668,7 @@ ogm_reader_c::read_headers_internal() {
     }
   }
 
-  m_in->setFilePointer(0, seek_beginning);
+  m_in->setFilePointer(0);
   ogg_sync_clear(&oy);
   ogg_sync_init(&oy);
 
@@ -853,13 +851,13 @@ ogm_reader_c::handle_stream_comments() {
             // auto cleaned = std::string{};
             // balg::copy_if(chapter_string, [](char c) { return c >= 0; }, std::back_inserter(cleaned));
             brng::remove_erase_if(chapter_string, [](char c) { return c < 0; });
-            out->puts(chapter_string + std::string{"\n"});
+            out->puts(chapter_string + "\n"s);
           }
 
         } else {
           out->write_bom("UTF-8");
           for (auto &chapter_string : chapter_strings)
-            out->puts(cch->utf8(chapter_string) + std::string{"\n"});
+            out->puts(cch->utf8(chapter_string) + "\n"s);
         }
 
         out->set_file_name(m_ti.m_fname);
@@ -958,7 +956,7 @@ ogm_demuxer_c::process_page(int64_t /* granulepos */) {
     int duration_len;
     get_duration_and_len(op, duration, duration_len);
 
-    memory_c *mem = new memory_c(&op.packet[duration_len + 1], op.bytes - 1 - duration_len, false);
+    auto mem = memory_c::borrow(&op.packet[duration_len + 1], op.bytes - 1 - duration_len);
     reader->m_reader_packetizers[ptzr]->process(new packet_t(mem));
     units_processed += op.bytes - 1;
   }
@@ -1166,7 +1164,7 @@ ogm_a_vorbis_demuxer_c::process_page(int64_t /* granulepos */) {
     if (((*op.packet & 3) == PACKET_TYPE_HEADER) || ((*op.packet & 3) == PACKET_TYPE_COMMENT))
       continue;
 
-    reader->m_reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false)));
+    reader->m_reader_packetizers[ptzr]->process(new packet_t(memory_c::borrow(op.packet, op.bytes)));
   }
 }
 
@@ -1174,7 +1172,7 @@ ogm_a_vorbis_demuxer_c::process_page(int64_t /* granulepos */) {
 
 ogm_a_opus_demuxer_c::ogm_a_opus_demuxer_c(ogm_reader_c *p_reader)
   : ogm_demuxer_c(p_reader)
-  , m_calculated_end_timestamp{timestamp_c::ns(0)}
+  , m_timestamp_shift{timestamp_c::ns(0)}
 {
   codec = codec_c::look_up(codec_c::type_e::A_OPUS);
 }
@@ -1193,31 +1191,119 @@ void
 ogm_a_opus_demuxer_c::process_page(int64_t granulepos) {
   ogg_packet op;
 
-  auto ogg_timestamp = timestamp_c::ns(granulepos * 1000000000 / 48000);
+  auto page_end_timestamp = timestamp_c::ns(granulepos * 1000000000 / 48000);
+  auto page_duration      = timestamp_c::ns(0);
+  auto packets            = std::vector<std::pair<packet_cptr, mtx::opus::toc_t>>{};
+  auto is_first_packet    = !m_previous_page_end_timestamp.valid();
+  auto eos_here           = false;
+  auto gap_here           = false;
 
-  while (ogg_stream_packetout(&os, &op) == 1) {
-    eos |= op.e_o_s;
+  while (true) {
+    auto result = ogg_stream_packetout(&os, &op);
+    if (result == 0)
+      break;
+
+    if (result == -1) {
+      gap_here = true;
+      continue;
+    }
+
+    if (op.e_o_s) {
+      eos      = 1;
+      eos_here = true;
+    }
 
     if ((4 <= op.bytes) && !memcmp(op.packet, "Opus", 4))
       continue;
 
     try {
-      auto packet                = std::make_shared<packet_t>(memory_c::clone(op.packet, op.bytes));
-      auto toc                   = mtx::opus::toc_t::decode(packet->data);
-      m_calculated_end_timestamp += toc.packet_duration;
+      auto packet    = std::make_shared<packet_t>(memory_c::clone(op.packet, op.bytes));
+      auto toc       = mtx::opus::toc_t::decode(packet->data);
+      page_duration += toc.packet_duration;
 
-      if (m_calculated_end_timestamp > ogg_timestamp) {
-        packet->discard_padding = m_calculated_end_timestamp - ogg_timestamp;
-        mxdebug_if(ms_debug,
-                   boost::format("Opus discard padding calculated %1% Ogg timestamp %2% diff %3% samples %4% (Ogg page's granulepos %5%)\n")
-                   % m_calculated_end_timestamp % ogg_timestamp % packet->discard_padding % (packet->discard_padding.to_ns() * 48000 / 1000000000) % granulepos);
-      }
+      packets.emplace_back(packet, toc);
 
-      reader->m_reader_packetizers[ptzr]->process(packet);
     } catch (mtx::opus::decode_error &ex) {
-      mxwarn_fn(m_ti.m_fname, boost::format(Y("Error decoding an Ogg Opus page at source timestamp %1%; page will be skipped: %2%\n")) % format_timestamp(ogg_timestamp) % ex);
+      mxwarn_fn(m_ti.m_fname, boost::format(Y("Error decoding an Ogg Opus page at source timestamp %1%; page will be skipped: %2%\n")) % page_end_timestamp % ex);
     }
   }
+
+  mxdebug_if(ms_debug,
+             boost::format("process_page: granulepos %1% = %2% previous page end timestamp %3% page duration %4% is_first_packet %5% eos_here %6% gap_here %7% num packets %8%\n")
+             % granulepos % page_end_timestamp % m_previous_page_end_timestamp % page_duration % is_first_packet % eos_here % gap_here % packets.size());
+
+  if (packets.empty())
+    return;
+
+  if (!eos_here && (is_first_packet || gap_here)) {
+    // Two possible situations that require calculating the start
+    // timestamps backwards from the granule position:
+
+    // 1. First page in Ogg stream. Streams must not start at 0. If
+    //    they don't, this is signaled by the page containing less
+    //    samples than the difference between the page's
+    //    granulepos-indicated end timestamp and 0.
+
+    // 2. If there was a gap, the calculated prior end timestamp is
+    //    the one before the gap and must therefore not be used.
+    auto current_timestamp = page_end_timestamp;
+    auto idx               = packets.size();
+
+    while (idx > 0) {
+      --idx;
+
+      current_timestamp             -= packets[idx].second.packet_duration;
+      packets[idx].first->timestamp  = (current_timestamp + m_timestamp_shift).to_ns();
+    }
+
+
+    if (gap_here) {
+      mxdebug_if(ms_debug,
+                 boost::format("Opus packet after gap; Ogg page end timestamp %1% page duration %2% first timestamp %3%\n")
+                 % page_end_timestamp % page_duration % format_timestamp(packets.front().first->timestamp));
+
+    } else if (current_timestamp != timestamp_c::ns(0)) {
+      if (current_timestamp < timestamp_c::ns(0)) {
+        m_timestamp_shift = current_timestamp.negate();
+        for (auto const &pair : packets)
+          pair.first->timestamp += m_timestamp_shift.to_ns();
+      }
+
+      mxdebug_if(ms_debug,
+                 boost::format("Opus first packet's timestamp is not zero; Ogg page end timestamp %1% page duration %2% first timestamp %3% (Ogg page's granulepos %4%) shift %5%\n")
+                 % page_end_timestamp % page_duration % format_timestamp(packets.front().first->timestamp) % granulepos % m_timestamp_shift);
+    }
+
+  } else {
+    // Calculate discard padding based on previous end timestamp and
+    // number of samples in this page. This is done so that streams
+    // that aren't strictly spec-compliant (gaps in the middle =
+    // discard padding present not just on the very last packet) can
+    // be handled gracefully, too.
+
+    auto current_timestamp = m_previous_page_end_timestamp;
+
+    for (auto const &pair : packets) {
+      pair.first->timestamp  = (current_timestamp + m_timestamp_shift).to_ns();
+      current_timestamp     += pair.second.packet_duration;
+    }
+
+    auto &packet      = *packets.back().first;
+    auto samples_over = (current_timestamp - page_end_timestamp).to_ns() * 48'000 / 1'000'000'000;
+
+    if (samples_over > (eos_here ? 0 : 1)) {
+      packet.discard_padding = current_timestamp - page_end_timestamp;
+
+      mxdebug_if(ms_debug,
+                 boost::format("Opus discard padding calculated: previous Ogg page end timestamp %1% current Ogg page end timestamp %2% discard padding %3% in samples %4% (Ogg page's granulepos %5%)\n")
+                 % m_previous_page_end_timestamp % page_end_timestamp % packet.discard_padding % samples_over % granulepos);
+    }
+  }
+
+   m_previous_page_end_timestamp = page_end_timestamp;
+
+   for (auto const &packet : packets)
+      reader->m_reader_packetizers[ptzr]->process(packet.first);
 }
 
 void
@@ -1237,7 +1323,7 @@ ogm_s_text_demuxer_c::ogm_s_text_demuxer_c(ogm_reader_c *p_reader)
 
 generic_packetizer_c *
 ogm_s_text_demuxer_c::create_packetizer() {
-  generic_packetizer_c *ptzr_obj = new textsubs_packetizer_c(reader, m_ti, MKV_S_TEXTUTF8, true, false);
+  auto ptzr_obj = new textsubs_packetizer_c(reader, m_ti, MKV_S_TEXTUTF8, true);
 
   show_packetizer_info(m_ti.m_id, ptzr_obj);
 
@@ -1261,7 +1347,7 @@ ogm_s_text_demuxer_c::process_page(int64_t granulepos) {
     get_duration_and_len(op, duration, duration_len);
 
     if (((op.bytes - 1 - duration_len) > 2) || ((op.packet[duration_len + 1] != ' ') && (op.packet[duration_len + 1] != 0) && !iscr(op.packet[duration_len + 1]))) {
-      memory_c *mem = new memory_c(&op.packet[duration_len + 1], op.bytes - 1 - duration_len, false);
+      auto mem = memory_c::borrow(&op.packet[duration_len + 1], op.bytes - 1 - duration_len);
       reader->m_reader_packetizers[ptzr]->process(new packet_t(mem, granulepos * 1000000, (int64_t)duration * 1000000));
     }
   }
@@ -1386,7 +1472,7 @@ ogm_v_mscomp_demuxer_c::process_page(int64_t granulepos) {
       duration = 1;
 
     ogm_frame_t frame = {
-      new memory_c(&op.packet[duration_len + 1], op.bytes - 1 - duration_len, false),
+      memory_c::clone(&op.packet[duration_len + 1], op.bytes - 1 - duration_len),
       duration * default_duration,
       op.packet[0],
     };
@@ -1420,8 +1506,6 @@ ogm_v_theora_demuxer_c::ogm_v_theora_demuxer_c(ogm_reader_c *p_reader)
   : ogm_demuxer_c(p_reader)
 {
   codec = codec_c::look_up(codec_c::type_e::V_THEORA);
-
-  memset(&theora, 0, sizeof(theora_identification_header_t));
 }
 
 void
@@ -1469,7 +1553,7 @@ ogm_v_theora_demuxer_c::process_page(int64_t granulepos) {
 
     ++units_processed;
 
-    reader->m_reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false), timestamp, duration, bref, VFT_NOBFRAME));
+    reader->m_reader_packetizers[ptzr]->process(new packet_t(memory_c::borrow(op.packet, op.bytes), timestamp, duration, bref, VFT_NOBFRAME));
 
     mxverb(3,
            boost::format("Theora track %1% kfgshift %2% granulepos 0x%|3$08x| %|4$08x|%5%\n")
@@ -1537,8 +1621,7 @@ ogm_v_vp8_demuxer_c::create_packetizer() {
 
   ptzr_obj->set_video_pixel_width(pixel_width);
   ptzr_obj->set_video_pixel_height(pixel_height);
-  ptzr_obj->set_video_display_width(display_width);
-  ptzr_obj->set_video_display_height(display_height);
+  ptzr_obj->set_video_display_dimensions(display_width, display_height, generic_packetizer_c::ddu_pixels, OPTION_SOURCE_BITSTREAM);
   ptzr_obj->set_track_default_duration(default_duration);
 
   show_packetizer_info(m_ti.m_id, ptzr_obj);
@@ -1616,8 +1699,6 @@ ogm_s_kate_demuxer_c::ogm_s_kate_demuxer_c(ogm_reader_c *p_reader)
   : ogm_demuxer_c(p_reader)
 {
   codec = codec_c::look_up(codec_c::type_e::S_KATE);
-
-  memset(&kate, 0, sizeof(kate_identification_header_t));
 }
 
 void
@@ -1650,7 +1731,7 @@ ogm_s_kate_demuxer_c::process_page(int64_t /* granulepos */) {
     if ((0 == op.bytes) || (0 != (op.packet[0] & 0x80)))
       continue;
 
-    reader->m_reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false)));
+    reader->m_reader_packetizers[ptzr]->process(new packet_t(memory_c::borrow(op.packet, op.bytes)));
 
     ++units_processed;
 
