@@ -98,6 +98,13 @@ struct qt_chunkmap_t {
 struct qt_editlist_t {
   int64_t  segment_duration{}, media_time{};
   uint16_t media_rate_integer{}, media_rate_fraction{};
+
+  bool operator ==(qt_editlist_t const &other) const {
+    return (segment_duration    == other.segment_duration)
+        && (media_time          == other.media_time)
+        && (media_rate_integer  == other.media_rate_integer)
+        && (media_rate_fraction == other.media_rate_fraction);
+  };
 };
 
 struct qt_sample_t {
@@ -305,7 +312,6 @@ struct qtmp4_demuxer_c {
     , m_debug_indexes{         "qtmp4_full|qtmp4_indexes|qtmp4_indexes_full"}
     , m_debug_indexes_full{                             "qtmp4_indexes_full"}
   {
-    memset(&esds, 0, sizeof(esds_t));
   }
 
   ~qtmp4_demuxer_c() {
@@ -453,6 +459,9 @@ private:
   qtmp4_demuxer_c *m_track_for_fragment;
 
   bool m_timestamps_calculated;
+  boost::optional<uint64_t> m_duration;
+
+  int64_t m_bytes_to_process{}, m_bytes_processed{};
 
   debugging_option_c m_debug_chapters, m_debug_headers, m_debug_tables, m_debug_tables_full, m_debug_interleaving, m_debug_resync;
 
@@ -467,8 +476,8 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
-  virtual int get_progress();
+  virtual int64_t get_progress() override;
+  virtual int64_t get_maximum_progress() override;
   virtual void identify();
   virtual void create_packetizers();
   virtual void create_packetizer(int64_t tid);
@@ -477,10 +486,14 @@ public:
   static int probe_file(mm_io_c &in, uint64_t size);
 
 protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   virtual void parse_headers();
   virtual void verify_track_parameters_and_update_indexes();
   virtual void calculate_timestamps();
   virtual boost::optional<int64_t> calculate_global_min_timestamp() const;
+  virtual void calculate_num_bytes_to_process();
+
   virtual qt_atom_t read_atom(mm_io_c *read_from = nullptr, bool exit_on_error = true);
   virtual bool resync_to_top_level_atom(uint64_t start_pos);
   virtual void parse_itunsmpb(std::string data);
