@@ -31,6 +31,8 @@
 #include "output/p_realaudio.h"
 #include "output/p_generic_video.h"
 
+using namespace libmatroska;
+
 /*
    Description of the RealMedia file format:
    http://www.pcisys.net/~melanson/codecs/rmff.htm
@@ -65,9 +67,9 @@ mm_io_file_seek(void *file,
   if (!file)
     return -1;
 
-  seek_mode smode = SEEK_END == whence ? seek_end
-                  : SEEK_CUR == whence ? seek_current
-                  :                      seek_beginning;
+  seek_mode smode = SEEK_END == whence ? libebml::seek_end
+                  : SEEK_CUR == whence ? libebml::seek_current
+                  :                      libebml::seek_beginning;
   return static_cast<mm_io_c *>(file)->setFilePointer2(offset, smode) ? 0 : -1;
 }
 
@@ -105,10 +107,10 @@ real_reader_c::probe_file(mm_io_c &in,
     return 0;
 
   try {
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
     if (in.read(data, 4) != 4)
       return 0;
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
 
   } catch (...) {
     return 0;
@@ -135,7 +137,7 @@ real_reader_c::read_headers() {
     else
       throw mtx::input::open_x();
   }
-  m_in->setFilePointer(0, seek_beginning);
+  m_in->setFilePointer(0);
 
   done = false;
 
@@ -431,8 +433,8 @@ real_reader_c::read(generic_packetizer_c *,
     return finish();
   }
 
-  memory_c mem(size);
-  rmff_frame_t *frame = rmff_read_next_frame(file, mem.get_buffer());
+  auto mem   = memory_c::alloc(size);
+  auto frame = rmff_read_next_frame(file, mem->get_buffer());
 
   if (!frame) {
     if (file->num_packets_read < file->num_packets_in_chunk)
@@ -468,7 +470,7 @@ real_reader_c::read(generic_packetizer_c *,
       PTZR(dmx->ptzr)->set_displacement_maybe(timestamp);
     }
 
-    deliver_aac_frames(dmx, mem);
+    deliver_aac_frames(dmx, *mem);
 
   } else
     queue_audio_frames(dmx, mem, timestamp, frame->flags);
@@ -482,23 +484,23 @@ real_reader_c::read(generic_packetizer_c *,
 
 void
 real_reader_c::queue_one_audio_frame(real_demuxer_cptr dmx,
-                                     memory_c &mem,
+                                     memory_cptr const &mem,
                                      uint64_t timestamp,
                                      uint32_t flags) {
   rv_segment_cptr segment(new rv_segment_t);
 
-  segment->data  = memory_cptr(new memory_c(mem));
+  segment->data  = mem;
   segment->flags = flags;
   dmx->segments.push_back(segment);
 
   dmx->last_timestamp = timestamp;
 
-  mxverb_tid(2, m_ti.m_fname, dmx->track->id, boost::format("enqueueing one length %1% timestamp %2% flags 0x%|3$08x|\n") % mem.get_size() % timestamp % flags);
+  mxverb_tid(2, m_ti.m_fname, dmx->track->id, boost::format("enqueueing one length %1% timestamp %2% flags 0x%|3$08x|\n") % mem->get_size() % timestamp % flags);
 }
 
 void
 real_reader_c::queue_audio_frames(real_demuxer_cptr dmx,
-                                  memory_c &mem,
+                                  memory_cptr const &mem,
                                   uint64_t timestamp,
                                   uint32_t flags) {
   // Enqueue the packets if no packets are in the queue or if the current
@@ -572,16 +574,11 @@ real_reader_c::deliver_aac_frames(real_demuxer_cptr dmx,
   int data_idx = 2 + num_sub_packets * 2;
   for (i = 0; i < num_sub_packets; i++) {
     int sub_length = get_uint16_be(&chunk[2 + i * 2]);
-    PTZR(dmx->ptzr)->process(new packet_t(new memory_c(&chunk[data_idx], sub_length, false)));
+    PTZR(dmx->ptzr)->process(new packet_t(memory_c::borrow(&chunk[data_idx], sub_length)));
     data_idx += sub_length;
   }
 }
 
-int
-real_reader_c::get_progress() {
-  return 100 * file->num_packets_read / file->num_packets_in_chunk;
-}
-
 void
 real_reader_c::identify() {
   id_result_container();
@@ -621,8 +618,11 @@ real_reader_c::assemble_video_packet(real_demuxer_cptr dmx,
     if (!dmx->rv_dimensions)
       set_dimensions(dmx, assembled->data, assembled->size);
 
-    packet_t *packet = new packet_t(new memory_c(assembled->data, assembled->size, true), (int64_t)assembled->timecode * 1000000, 0,
-                                    (assembled->flags & RMFF_FRAME_FLAG_KEYFRAME) == RMFF_FRAME_FLAG_KEYFRAME ? VFT_IFRAME : VFT_PFRAMEAUTOMATIC, VFT_NOBFRAME);
+    auto packet = std::make_shared<packet_t>(memory_c::take_ownership(assembled->data, assembled->size),
+                                             (int64_t)assembled->timecode * 1000000,
+                                             0,
+                                             (assembled->flags & RMFF_FRAME_FLAG_KEYFRAME) == RMFF_FRAME_FLAG_KEYFRAME ? VFT_IFRAME : VFT_PFRAMEAUTOMATIC,
+                                             VFT_NOBFRAME);
     PTZR(dmx->ptzr)->process(packet);
 
     assembled->allocated_by_rmff = 0;
@@ -780,7 +780,7 @@ real_reader_c::get_information_from_data() {
     }
   }
 
-  m_in->setFilePointer(old_pos, seek_beginning);
+  m_in->setFilePointer(old_pos);
   file->num_packets_read = 0;
 }
 
