@@ -54,12 +54,12 @@ vobsub_reader_c::probe_file(mm_io_c &in,
   char chunk[80];
 
   try {
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
     if (in.read(chunk, 80) != 80)
       return 0;
     if (strncasecmp(chunk, id_string.c_str(), id_string.length()))
       return 0;
-    in.setFilePointer(0, seek_beginning);
+    in.setFilePointer(0);
   } catch (...) {
     return 0;
   }
@@ -153,7 +153,10 @@ vobsub_reader_c::create_packetizer(int64_t tid) {
     avg_duration /= (track->entries.size() - 1);
   track->entries[track->entries.size() - 1].duration = avg_duration;
 
-  num_indices += track->entries.size();
+  for (int idx = 0, end = track->entries.size(); idx < end; ++idx) {
+    auto end_position   = (idx + 1) < end ? track->entries[idx + 1].position : m_in->get_size();
+    m_bytes_to_process += end_position - track->entries[idx].position;
+  }
 
   m_ti.m_language = "";
   show_packetizer_info(tid, PTZR(track->ptzr));
@@ -174,10 +177,8 @@ vobsub_reader_c::parse_headers() {
   int64_t line_no        = 0;
   int64_t last_timestamp = 0;
   bool sort_required     = false;
-  num_indices            = 0;
-  indices_processed      = 0;
 
-  m_idx_file->setFilePointer(0, seek_beginning);
+  m_idx_file->setFilePointer(0);
 
   while (1) {
     if (!m_idx_file->getline2(line))
@@ -360,7 +361,7 @@ vobsub_reader_c::deliver_packet(unsigned char *buf,
     // Some players ignore sub-pictures if there is no stop display command.
     // Add a stop display command only if 1 command chain exists and the hack is enabled.
 
-    if ((dcsq == dcsq2) && hack_engaged(ENGAGE_VOBSUB_SUBPIC_STOP_CMDS)) {
+    if ((dcsq == dcsq2) && mtx::hacks::is_engaged(mtx::hacks::VOBSUB_SUBPIC_STOP_CMDS)) {
       dcsq         += 2;        // points to first command chain
       dcsq2        += 4;        // find end of first command chain
       bool unknown  = false;
@@ -414,7 +415,7 @@ vobsub_reader_c::deliver_packet(unsigned char *buf,
   }
 
   if (duration.valid())
-    ptzr->process(new packet_t(new memory_c(buf, size, true), timestamp, duration.to_ns()));
+    ptzr->process(new packet_t(memory_c::take_ownership(buf, size), timestamp, duration.to_ns()));
   else
     safefree(buf);
 
@@ -431,7 +432,7 @@ vobsub_reader_c::extract_one_spu_packet(int64_t track_id) {
   unsigned char buf[5];
 
   vobsub_track_c *track         = tracks[track_id];
-  int64_t timestamp              = track->entries[track->idx].timestamp;
+  int64_t timestamp             = track->entries[track->idx].timestamp;
   int64_t duration              = track->entries[track->idx].duration;
   uint64_t extraction_start_pos = track->entries[track->idx].position;
   uint64_t extraction_end_pos   = track->idx >= track->entries.size() - 1 ? m_sub_file->get_size() : track->entries[track->idx + 1].position;
@@ -443,6 +444,8 @@ vobsub_reader_c::extract_one_spu_packet(int64_t track_id) {
   unsigned int spu_len          = 0;
   bool spu_len_valid            = false;
 
+  m_bytes_processed            += extraction_end_pos - extraction_start_pos;
+
   m_sub_file->setFilePointer(extraction_start_pos);
   track->packet_num++;
 
@@ -549,7 +552,7 @@ vobsub_reader_c::extract_one_spu_packet(int64_t track_id) {
               pts = ((int64_t)((buf[0] & 0x0e) << 29 | buf[1] << 22 | (buf[2] & 0xfe) << 14 | buf[3] << 7 | (buf[4] >> 1))) * 100000 / 9;
           }
 
-          m_sub_file->setFilePointer2(dataidx + extraction_start_pos, seek_beginning);
+          m_sub_file->setFilePointer2(dataidx + extraction_start_pos);
           packet_aid = m_sub_file->getch();
           if (0 > packet_aid) {
             mxwarn_fn(m_ti.m_fname, boost::format(Y("Bogus aid %1%\n")) % packet_aid);
@@ -569,7 +572,7 @@ vobsub_reader_c::extract_one_spu_packet(int64_t track_id) {
             break;
           }
 
-          if (hack_engaged(ENGAGE_VOBSUB_SUBPIC_STOP_CMDS)) {
+          if (mtx::hacks::is_engaged(mtx::hacks::VOBSUB_SUBPIC_STOP_CMDS)) {
             // Space for the stop display command and padding
             dst_buf = (unsigned char *)saferealloc(dst_buf, dst_size + packet_size + 6);
             memset(dst_buf + dst_size + packet_size, 0xff, 6);
@@ -642,14 +645,18 @@ vobsub_reader_c::read(generic_packetizer_c *ptzr,
 
   extract_one_spu_packet(id);
   track->idx++;
-  indices_processed++;
 
   return track->idx >= track->entries.size() ? flush_packetizers() : FILE_STATUS_MOREDATA;
 }
 
-int
+int64_t
 vobsub_reader_c::get_progress() {
-  return 100 * indices_processed / num_indices;
+  return m_bytes_processed;
+}
+
+int64_t
+vobsub_reader_c::get_maximum_progress() {
+  return m_bytes_to_process;
 }
 
 void
