@@ -19,7 +19,6 @@
 #include "common/codec.h"
 #include "common/dts.h"
 #include "common/error.h"
-#include "common/mm_io.h"
 #include "merge/generic_reader.h"
 
 class wav_reader_c;
@@ -96,18 +95,19 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t tid);
   virtual bool is_providing_timestamps() const {
     return false;
   }
 
-  static int probe_file(mm_io_c *in, uint64_t size);
+  static int probe_file(mm_io_c &in, uint64_t size);
 
 protected:
   static type_e determine_type(mm_io_c &in, uint64_t size);
 
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   boost::optional<std::size_t> find_chunk(const char *id, int start_idx = 0, bool allow_empty = true);
 
   void scan_chunks();
