@@ -61,6 +61,16 @@ public:
   bool empty() {
     return current == entries.end();
   }
+
+  int64_t get_total_byte_size() {
+    return boost::accumulate(entries, 0ull, [](int64_t num, auto const &entry) { return num + entry.subs.length(); });
+  }
+
+  int64_t get_next_byte_size() {
+    if (empty() || (entries.end() == current))
+      return 0;
+    return current->subs.length();
+  }
 };
 using subtitles_cptr = std::shared_ptr<subtitles_c>;
 
@@ -106,7 +116,7 @@ protected:
   int64_t m_tid;
   charset_converter_cptr m_cc_utf8;
   std::vector<std::string> m_format;
-  bool m_is_ass;
+  bool m_is_ass, m_try_utf8{}, m_invalid_utf8_warned{};
   std::string m_global;
   int64_t m_attachment_id;
 
@@ -121,9 +131,7 @@ public:
     return m_is_ass;
   }
 
-  void set_charset_converter(charset_converter_cptr cc_utf8) {
-    m_cc_utf8 = cc_utf8;
-  }
+  void set_charset_converter(charset_converter_cptr const &cc_utf8);
 
   std::string get_global() {
     return m_global;
@@ -139,7 +147,7 @@ public:
 protected:
   int64_t parse_time(std::string &time);
   std::string get_element(const char *index, std::vector<std::string> &fields);
-  std::string recode_text(std::vector<std::string> &fields);
+  std::string recode(std::string const &s, uint32_t replacement_marker = 0xfffdu);
   void add_attachment_maybe(std::string &name, std::string &data_uu, ssa_section_e section);
   void decode_chars(unsigned char const *in, unsigned char *out, size_t bytes_in);
 };
