@@ -17,7 +17,6 @@
 #include "common/doc_type_version_handler.h"
 #include "common/ebml.h"
 #include "common/hacks.h"
-#include "common/math.h"
 #include "common/strings/formatting.h"
 #include "common/tags/tags.h"
 #include "common/translation.h"
@@ -35,6 +34,8 @@
 #include <matroska/KaxCuesData.h>
 #include <matroska/KaxSeekHead.h>
 
+using namespace libmatroska;
+
 debugging_option_c render_groups_c::ms_gap_detection{"cluster_helper_gap_detection"};
 
 cluster_helper_c::impl_t::~impl_t() {
@@ -46,13 +47,6 @@ cluster_helper_c::cluster_helper_c()
 }
 
 cluster_helper_c::~cluster_helper_c() {
-  // If rendering fails e.g. due to the file system being full, the
-  // cleanup code can run into access-after-free and
-  // free-multiple-times situations due to blocks still being present
-  // in the cluster. Therefore just dump them as cluster_helper_c is a
-  // singleton class.
-  if (m && m->cluster)
-    m->cluster->RemoveAll();
 }
 
 mm_io_c *
@@ -385,9 +379,9 @@ cluster_helper_c::render() {
   kax_cues_with_cleanup_c cues;
   cues.SetGlobalTimecodeScale(g_timestamp_scale);
 
-  bool use_simpleblock     = !hack_engaged(ENGAGE_NO_SIMPLE_BLOCKS);
+  bool use_simpleblock     = !mtx::hacks::is_engaged(mtx::hacks::NO_SIMPLE_BLOCKS);
 
-  LacingType lacing_type   = hack_engaged(ENGAGE_LACING_XIPH) ? LACING_XIPH : hack_engaged(ENGAGE_LACING_EBML) ? LACING_EBML : LACING_AUTO;
+  LacingType lacing_type   = mtx::hacks::is_engaged(mtx::hacks::LACING_XIPH) ? LACING_XIPH : mtx::hacks::is_engaged(mtx::hacks::LACING_EBML) ? LACING_EBML : LACING_AUTO;
 
   int64_t min_cl_timestamp = std::numeric_limits<int64_t>::max();
   int64_t max_cl_timestamp = 0;
@@ -699,17 +693,19 @@ cluster_helper_c::dump_split_points()
   const {
   mxdebug_if(m->debug_splitting,
              boost::format("Split points:%1%\n")
-             % boost::accumulate(m->split_points, std::string(""), [](std::string const &accu, split_point_c const &point) { return accu + " " + point.str(); }));
+             % boost::accumulate(m->split_points, ""s, [](std::string const &accu, split_point_c const &point) { return accu + " " + point.str(); }));
 }
 
 void
 cluster_helper_c::create_tags_for_track_statistics(KaxTags &tags,
                                                    std::string const &writing_app,
                                                    boost::posix_time::ptime const &writing_date) {
+  auto actual_writing_date = g_write_date ? boost::optional<boost::posix_time::ptime>{writing_date} : boost::optional<boost::posix_time::ptime>{};
+
   for (auto const &ptzr : g_packetizers) {
     auto track_uid = ptzr.packetizer->get_uid();
 
-    m->track_statistics[track_uid].set_track_uid(track_uid).create_tags(tags, writing_app, writing_date);
+    m->track_statistics[track_uid].set_track_uid(track_uid).create_tags(tags, writing_app, actual_writing_date);
   }
 
   m->track_statistics.clear();
