@@ -18,13 +18,14 @@
 #include "common/ebml.h"
 #include "common/fs_sys_helpers.h"
 #include "common/hacks.h"
-#include "common/math.h"
 #include "merge/cluster_helper.h"
 #include "merge/cues.h"
 #include "merge/generic_packetizer.h"
 #include "merge/libmatroska_extensions.h"
 #include "merge/output_control.h"
 
+using namespace libmatroska;
+
 cues_cptr cues_c::s_cues;
 
 cues_c::cues_c()
