@@ -38,6 +38,8 @@
 #include "merge/output_control.h"
 #include "merge/webm.h"
 
+using namespace libmatroska;
+
 #define TRACK_TYPE_TO_DEFTRACK_TYPE(track_type)      \
   (  track_audio == track_type ? DEFTRACK_TYPE_AUDIO \
    : track_video == track_type ? DEFTRACK_TYPE_VIDEO \
@@ -82,6 +84,7 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *reader,
   , m_hvideo_pixel_height{-1}
   , m_hvideo_display_width{-1}
   , m_hvideo_display_height{-1}
+  , m_hvideo_display_unit{ddu_pixels}
   , m_hcompression{COMPRESSION_UNSPECIFIED}
   , m_timestamp_factory_application_mode{TFA_AUTOMATIC}
   , m_last_cue_timestamp{-1}
@@ -183,7 +186,7 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *reader,
   if (-2 != i) {
     display_properties_t &dprop = m_ti.m_display_properties[i];
     if (0 > dprop.aspect_ratio) {
-      set_video_display_dimensions(dprop.width, dprop.height, OPTION_SOURCE_COMMAND_LINE);
+      set_video_display_dimensions(dprop.width, dprop.height, generic_packetizer_c::ddu_pixels, OPTION_SOURCE_COMMAND_LINE);
     } else {
       set_video_aspect_ratio(dprop.aspect_ratio, dprop.ar_factor, OPTION_SOURCE_COMMAND_LINE);
       m_ti.m_aspect_ratio_given = true;
@@ -581,22 +584,33 @@ generic_packetizer_c::set_video_display_height(int height) {
     GetChild<KaxVideoDisplayHeight>(GetChild<KaxTrackVideo>(*m_track_entry)).SetValue(m_hvideo_display_height);
 }
 
+void
+generic_packetizer_c::set_video_display_unit(int unit) {
+  m_hvideo_display_unit = unit;
+  if (   m_track_entry
+      && (   (unit != ddu_pixels)
+          || (unit != FindChildValue<KaxVideoDisplayUnit>(GetChild<KaxTrackVideo>(*m_track_entry), ddu_pixels))))
+    GetChild<KaxVideoDisplayUnit>(GetChild<KaxTrackVideo>(*m_track_entry)).SetValue(m_hvideo_display_unit);
+}
+
 void
 generic_packetizer_c::set_video_display_dimensions(int width,
                                                    int height,
+                                                   int unit,
                                                    option_source_e source) {
   if (display_dimensions_or_aspect_ratio_set() && (m_ti.m_display_dimensions_source >= source))
     return;
 
   m_ti.m_display_width             = width;
   m_ti.m_display_height            = height;
+  m_ti.m_display_unit              = unit;
   m_ti.m_display_dimensions_source = source;
   m_ti.m_display_dimensions_given  = true;
   m_ti.m_aspect_ratio_given        = false;
 
   set_video_display_width(width);
   set_video_display_height(height);
-
+  set_video_display_unit(unit);
 }
 
 void
@@ -608,6 +622,7 @@ generic_packetizer_c::set_video_aspect_ratio(double aspect_ratio,
 
   m_ti.m_aspect_ratio              = aspect_ratio;
   m_ti.m_aspect_ratio_is_factor    = is_factor;
+  m_ti.m_display_unit              = ddu_pixels;
   m_ti.m_display_dimensions_source = source;
   m_ti.m_display_dimensions_given  = false;
   m_ti.m_aspect_ratio_given        = true;
@@ -936,6 +951,15 @@ generic_packetizer_c::set_video_stereo_mode_impl(EbmlMaster &video,
   GetChild<KaxVideoStereoMode>(video).SetValue(stereo_mode);
 }
 
+void
+generic_packetizer_c::set_video_colour_space(memory_cptr const &value,
+                                             option_source_e source) {
+  m_ti.m_colour_space.set(value, source);
+
+  if (m_track_entry && value && value->get_size())
+    GetChild<KaxVideoColourSpace>(m_track_entry).CopyBuffer(value->get_buffer(), value->get_size());
+}
+
 void
 generic_packetizer_c::set_headers() {
   if (0 < m_connected_to) {
@@ -1051,6 +1075,12 @@ generic_packetizer_c::set_headers() {
       GetChild<KaxVideoDisplayWidth >(video).SetDefaultSize(4);
       GetChild<KaxVideoDisplayHeight>(video).SetDefaultSize(4);
 
+      if (m_hvideo_display_unit != ddu_pixels)
+        GetChild<KaxVideoDisplayUnit>(video).SetValue(m_hvideo_display_unit);
+
+      if (m_ti.m_colour_space)
+        GetChild<KaxVideoColourSpace>(video).CopyBuffer(m_ti.m_colour_space.get()->get_buffer(), m_ti.m_colour_space.get()->get_size());
+
       if (m_ti.m_pixel_cropping) {
         auto crop = m_ti.m_pixel_cropping.get();
         GetChild<KaxVideoPixelCropLeft  >(video).SetValue(crop.left);
@@ -1230,8 +1260,7 @@ generic_packetizer_c::set_headers() {
   set_tag_track_uid();
   if (m_ti.m_tags) {
     while (m_ti.m_tags->ListSize() != 0) {
-      KaxTag *tag = (KaxTag *)(*m_ti.m_tags)[0];
-      add_tags(tag);
+      add_tags(static_cast<KaxTag &>(*(*m_ti.m_tags)[0]));
       m_ti.m_tags->Remove(0);
     }
   }
@@ -1282,9 +1311,9 @@ generic_packetizer_c::add_packet(packet_cptr pack) {
       && (pack->data_adds.size()  > static_cast<size_t>(m_htrack_max_add_block_ids)))
     pack->data_adds.resize(m_htrack_max_add_block_ids);
 
-  pack->data->grab();
+  pack->data->take_ownership();
   for (auto &data_add : pack->data_adds)
-    data_add->grab();
+    data_add->take_ownership();
 
   pack->source = this;
 
@@ -1320,7 +1349,7 @@ generic_packetizer_c::add_packet2(packet_cptr pack) {
   // 'timestamp < safety_last_timestamp' may only occur for B frames. In this
   // case we have the coding order, e.g. IPB1B2 and the timestamps
   // I: 0, P: 120, B1: 40, B2: 80.
-  if (!m_relaxed_timestamp_checking && (pack->timestamp < m_safety_last_timestamp) && (0 > pack->fref) && hack_engaged(ENGAGE_ENABLE_TIMESTAMP_WARNING)) {
+  if (!m_relaxed_timestamp_checking && (pack->timestamp < m_safety_last_timestamp) && (0 > pack->fref) && mtx::hacks::is_engaged(mtx::hacks::ENABLE_TIMESTAMP_WARNING)) {
     if (track_audio == m_htrack_type) {
       int64_t needed_timestamp_offset  = m_safety_last_timestamp + m_safety_last_duration - pack->timestamp;
       m_correction_timestamp_offset   += needed_timestamp_offset;
@@ -1528,7 +1557,7 @@ int64_t
 generic_packetizer_c::calculate_avi_audio_sync(int64_t num_bytes,
                                                int64_t samples_per_packet,
                                                int64_t packet_duration) {
-  if (!m_ti.m_avi_audio_sync_enabled || hack_engaged(ENGAGE_NO_DELAY_FOR_GARBAGE_IN_AVI))
+  if (!m_ti.m_avi_audio_sync_enabled || mtx::hacks::is_engaged(mtx::hacks::NO_DELAY_FOR_GARBAGE_IN_AVI))
     return -1;
 
   if (m_ti.m_avi_audio_data_rate)
@@ -1659,7 +1688,7 @@ generic_packetizer_c::create_track_number() {
 
 file_status_e
 generic_packetizer_c::read(bool force) {
-  return m_reader->read(this, force);
+  return m_reader->read_next(this, force);
 }
 
 void
