@@ -19,17 +19,15 @@
 
 #include "common/file_types.h"
 #include "common/chapters/chapters.h"
+#include "common/math_fwd.h"
 #include "common/translation.h"
 #include "merge/file_status.h"
 #include "merge/id_result.h"
-#include "common/math.h"
 #include "merge/packet.h"
 #include "merge/timestamp_factory.h"
 #include "merge/track_info.h"
 #include "merge/webm.h"
 
-using namespace libmatroska;
-
 class generic_packetizer_c;
 
 #define DEFTRACK_TYPE_AUDIO 0
@@ -83,9 +81,10 @@ public:
   virtual timestamp_c const &get_timestamp_restriction_max() const;
 
   virtual void read_headers() = 0;
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) = 0;
+  virtual file_status_e read_next(generic_packetizer_c *ptzr, bool force = false);
   virtual void read_all();
-  virtual int get_progress();
+  virtual int64_t get_progress();
+  virtual int64_t get_maximum_progress();
   virtual void set_headers();
   virtual void set_headers_for_track(int64_t tid);
   virtual void identify() = 0;
@@ -129,6 +128,8 @@ public:
 public:
   static void set_probe_range_percentage(int64_rational_c const &probe_range_percentage);
 
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) = 0;
+
 protected:
   virtual bool demuxing_requested(char type, int64_t id, boost::optional<std::string> const &language = boost::none) const;
 
@@ -139,8 +140,6 @@ protected:
   virtual void id_result_chapters(int num_entries);
   virtual void id_result_tags(int64_t track_id, int num_entries);
 
-  virtual std::string id_escape_string(const std::string &s);
-
   virtual mm_io_c *get_underlying_input(mm_io_c *actual_in = nullptr) const;
 
   virtual void display_identification_results_as_json();
