@@ -182,15 +182,14 @@ static mm_io_cptr s_out;
 
 static mtx::bits::value_c s_seguid_prev(128), s_seguid_current(128), s_seguid_next(128);
 
-static int s_display_files_done           = 0;
-static int s_display_path_length          = 1;
-static generic_reader_c *s_display_reader = nullptr;
-
 static std::unique_ptr<EbmlHead> s_head;
 
 static std::string s_muxing_app, s_writing_app;
 static boost::posix_time::ptime s_writing_date;
 
+static boost::optional<int64_t> s_maximum_progress;
+int64_t s_current_progress{};
+
 std::unique_ptr<mtx::doc_type_version_handler_c> g_doc_type_version_handler;
 
 /** \brief Add a segment family UID to the list if it doesn't exist already.
@@ -271,7 +270,7 @@ sighandler(int /* signum */) {
   mxinfo(Y(" done\n"));
 
   mxinfo(Y("The file is being fixed, part 3/4..."));
-  if ((g_kax_sh_main->ListSize() > 0) && !hack_engaged(ENGAGE_NO_META_SEEK)) {
+  if ((g_kax_sh_main->ListSize() > 0) && !mtx::hacks::is_engaged(mtx::hacks::NO_META_SEEK)) {
     g_kax_sh_main->UpdateSize();
     if (s_kax_sh_void->ReplaceWith(*g_kax_sh_main, *s_out, true) == INVALID_FILEPOS_T)
       mxwarn(boost::format(Y("This should REALLY not have happened. The space reserved for the first meta seek element was too small. %1%\n")) % BUGMSG);
@@ -295,24 +294,17 @@ sighandler(int /* signum */) {
 }
 #endif
 
-static generic_reader_c *
-determine_display_reader() {
-  if (g_video_packetizer)
-    return g_video_packetizer->m_reader;
+void
+add_to_progress(int64_t num_bytes_processed) {
+  s_current_progress += num_bytes_processed;
+}
 
-  auto winner = static_cast<filelist_t const *>(nullptr);
-  for (auto &current : g_files)
-    if (!current->appending && (0 != current->reader->get_num_packetizers()) && (!winner || (current->size > winner->size)))
-      winner = current.get();
+static int64_t
+get_maximum_progress() {
+  if (!s_maximum_progress)
+    s_maximum_progress = boost::accumulate(g_files, 0ull, [](int64_t num, auto const &file) { return num + file->reader->get_maximum_progress(); });
 
-  if (winner)
-    return winner->reader.get();
-
-  for (auto &current : g_files)
-    if (!current->appending && (!winner || (current->size > winner->size)))
-      winner = current.get();
-
-  return winner->reader.get();
+  return *s_maximum_progress;
 }
 
 /** \brief Selects a reader for displaying its progress information
@@ -334,11 +326,9 @@ display_progress(bool is_100percent = false) {
     return;
   }
 
-  if (!s_display_reader)
-    s_display_reader = determine_display_reader();
-
   bool display_progress  = false;
-  int current_percentage = (s_display_reader->get_progress() + s_display_files_done * 100) / s_display_path_length;
+  auto maximum_progress  = get_maximum_progress();
+  int current_percentage = maximum_progress ? (s_current_progress * 100) / maximum_progress : 0;
   int64_t current_time   = mtx::sys::get_current_time_millis();
 
   if (   (-1 == s_previous_percentage)
@@ -364,14 +354,16 @@ display_progress(bool is_100percent = false) {
 /** \brief Add some tags to the list of all tags
 */
 void
-add_tags(KaxTag *tags) {
-  if (tags->ListSize() == 0)
+add_tags(KaxTag &tags) {
+  if (tags.ListSize() == 0) {
+    delete &tags;
     return;
+  }
 
   if (!s_kax_tags)
     s_kax_tags = std::make_unique<KaxTags>();
 
-  s_kax_tags->PushElement(*tags);
+  s_kax_tags->PushElement(tags);
 }
 
 /** \brief Add an attachment
@@ -387,7 +379,7 @@ add_attachment(attachment_cptr const &attachment) {
   if (0 != attachment->id) {
     for (auto &ex_attachment : g_attachments)
       if ((   (ex_attachment->id == attachment->id)
-           && !hack_engaged(ENGAGE_NO_VARIABLE_DATA))
+           && !mtx::hacks::is_engaged(mtx::hacks::NO_VARIABLE_DATA))
           ||
           (   (ex_attachment->name             == attachment->name)
            && (ex_attachment->description      == attachment->description)
@@ -488,7 +480,7 @@ generate_segment_uids() {
     return;
 
   // Generate the segment UIDs.
-  if (hack_engaged(ENGAGE_NO_VARIABLE_DATA)) {
+  if (mtx::hacks::is_engaged(mtx::hacks::NO_VARIABLE_DATA)) {
     s_seguid_current.zero_content();
     s_seguid_next.zero_content();
     s_seguid_prev.zero_content();
@@ -897,7 +889,6 @@ render_attachments(mm_io_c &out) {
 */
 void
 check_append_mapping() {
-  std::vector<int64_t>::iterator id;
   std::vector<filelist_cptr>::iterator src_file, dst_file;
 
   for (auto &amap : g_append_mapping) {
@@ -1060,9 +1051,6 @@ check_append_mapping() {
           break;
         }
     } while (cmp_amap != amap_end);
-
-    if (path_length > s_display_path_length)
-      s_display_path_length = path_length;
   }
 }
 
@@ -1471,7 +1459,7 @@ finish_file(bool last_file,
     mxinfo("\n");
 
   // Render the track headers a second time if the user has requested that.
-  if (hack_engaged(ENGAGE_WRITE_HEADERS_TWICE)) {
+  if (mtx::hacks::is_engaged(mtx::hacks::WRITE_HEADERS_TWICE)) {
     auto second_tracks = clone(g_kax_tracks);
     g_doc_type_version_handler->render(*second_tracks, *s_out);
     g_kax_sh_main->IndexThis(*second_tracks, *g_kax_segment);
@@ -1536,7 +1524,7 @@ finish_file(bool last_file,
   s_out->restore_pos();
 
   // Render the segment info a second time if the user has requested that.
-  if (hack_engaged(ENGAGE_WRITE_HEADERS_TWICE)) {
+  if (mtx::hacks::is_engaged(mtx::hacks::WRITE_HEADERS_TWICE)) {
     g_doc_type_version_handler->render(*s_kax_infos, *s_out);
     g_kax_sh_main->IndexThis(*s_kax_infos, *g_kax_segment);
   }
@@ -1544,7 +1532,7 @@ finish_file(bool last_file,
   render_chapters();
 
   // Render the meta seek information with the cues
-  if (g_write_meta_seek_for_clusters && (g_kax_sh_cues->ListSize() > 0) && !hack_engaged(ENGAGE_NO_META_SEEK)) {
+  if (g_write_meta_seek_for_clusters && (g_kax_sh_cues->ListSize() > 0) && !mtx::hacks::is_engaged(mtx::hacks::NO_META_SEEK)) {
     g_kax_sh_cues->UpdateSize();
     g_doc_type_version_handler->render(*g_kax_sh_cues, *s_out);
     g_kax_sh_main->IndexThis(*g_kax_sh_cues, *g_kax_segment);
@@ -1578,7 +1566,7 @@ finish_file(bool last_file,
   }
 
   if (s_chapters_in_this_file) {
-    if (!hack_engaged(ENGAGE_NO_CHAPTERS_IN_META_SEEK))
+    if (!mtx::hacks::is_engaged(mtx::hacks::NO_CHAPTERS_IN_META_SEEK))
       g_kax_sh_main->IndexThis(*s_chapters_in_this_file, *g_kax_segment);
     s_chapters_in_this_file.reset();
   }
@@ -1588,7 +1576,7 @@ finish_file(bool last_file,
     s_kax_as.reset();
   }
 
-  if ((g_kax_sh_main->ListSize() > 0) && !hack_engaged(ENGAGE_NO_META_SEEK)) {
+  if ((g_kax_sh_main->ListSize() > 0) && !mtx::hacks::is_engaged(mtx::hacks::NO_META_SEEK)) {
     g_kax_sh_main->UpdateSize();
     if (s_kax_sh_void->ReplaceWith(*g_kax_sh_main, *s_out, true) == INVALID_FILEPOS_T)
       mxwarn(boost::format(Y("This should REALLY not have happened. The space reserved for the first meta seek element was too small. Size needed: %1%. %2%\n"))
@@ -1751,13 +1739,6 @@ append_track(packetizer_t &ptzr,
   mxinfo(boost::format(Y("Appending track %1% from file no. %2% ('%3%') to track %4% from file no. %5% ('%6%').\n"))
          % (*gptzr)->m_ti.m_id % amap.src_file_id % (*gptzr)->m_ti.m_fname % ptzr.packetizer->m_ti.m_id % amap.dst_file_id % ptzr.packetizer->m_ti.m_fname);
 
-  // Is the current file currently used for displaying the progress? If yes
-  // then replace it with the next one.
-  if (s_display_reader == dst_file.reader.get()) {
-    s_display_files_done++;
-    s_display_reader = src_file.reader.get();
-  }
-
   // Also fix the ptzr structure and reset the ptzr's state to "I want more".
   generic_packetizer_c *old_packetizer = ptzr.packetizer;
   ptzr.packetizer                      = *gptzr;
