@@ -243,7 +243,7 @@ public:
   std::string m_fourcc;
   std::map<int64_t, display_properties_t> m_display_properties;
   float m_aspect_ratio;
-  int m_display_width, m_display_height;
+  int m_display_width, m_display_height, m_display_unit;
   bool m_aspect_ratio_given, m_aspect_ratio_is_factor, m_display_dimensions_given;
   option_source_e m_display_dimensions_source;
 
@@ -276,7 +276,7 @@ public:
 
   std::map<int64_t, std::string> m_all_tags;     // As given on the command line
   std::string m_tags_file_name;        // For this very track
-  std::shared_ptr<KaxTags> m_tags;     // For this very track
+  std::shared_ptr<libmatroska::KaxTags> m_tags;     // For this very track
 
   std::map<int64_t, bool> m_all_aac_is_sbr; // For AAC+/HE-AAC/SBR
 
@@ -355,6 +355,9 @@ public:
   std::map<int64_t, double> m_projection_pose_roll_list; // As given on the command line
   option_with_source_c<double> m_projection_pose_roll; // For this very track
 
+  std::map<int64_t, memory_cptr> m_colour_space_list; // As given on the command line
+  option_with_source_c<memory_cptr> m_colour_space; // For this very track
+
   std::map<int64_t, std::pair<int64_t, bool>> m_default_durations; // As given on the command line
   std::map<int64_t, int> m_max_blockadd_ids; // As given on the command line
 
