@@ -10,10 +10,11 @@
 #include "mkvtoolnix-gui/chapter_editor/chapter_model.h"
 #include "mkvtoolnix-gui/util/model.h"
 
-namespace mtx { namespace gui { namespace ChapterEditor {
-
+using namespace libmatroska;
 using namespace mtx::gui;
 
+namespace mtx { namespace gui { namespace ChapterEditor {
+
 static auto const s_numColumns = 4;
 
 ChapterModel::ChapterModel(QObject *parent)
@@ -179,7 +180,7 @@ ChapterModel::chapterNameForLanguage(KaxChapterAtom &chapter,
     if (!kDisplay)
       continue;
 
-    auto actualLanguage = FindChildValue<KaxChapterLanguage>(kDisplay, std::string{"eng"});
+    auto actualLanguage = FindChildValue<KaxChapterLanguage>(kDisplay, "eng"s);
     if (language.empty() || (language == actualLanguage))
       return Q(FindChildValue<KaxChapterString>(kDisplay));
   }
