@@ -10,11 +10,9 @@
 
 // class QAbstractItemView;
 
-using namespace libmatroska;
-
-using ChaptersPtr = std::shared_ptr<KaxChapters>;
-using EditionPtr  = std::shared_ptr<KaxEditionEntry>;
-using ChapterPtr  = std::shared_ptr<KaxChapterAtom>;
+using ChaptersPtr = std::shared_ptr<libmatroska::KaxChapters>;
+using EditionPtr  = std::shared_ptr<libmatroska::KaxEditionEntry>;
+using ChapterPtr  = std::shared_ptr<libmatroska::KaxChapterAtom>;
 
 Q_DECLARE_METATYPE(EditionPtr);
 Q_DECLARE_METATYPE(ChapterPtr);
@@ -25,7 +23,7 @@ class ChapterModel: public QStandardItemModel {
   Q_OBJECT;
 
 protected:
-  QHash<qulonglong, std::shared_ptr<EbmlMaster>> m_elementRegistry;
+  QHash<qulonglong, std::shared_ptr<libebml::EbmlMaster>> m_elementRegistry;
   qulonglong m_nextElementRegistryIdx{};
 
   QModelIndex m_selectedIdx;
@@ -43,7 +41,7 @@ public:
   void removeTree(QModelIndex const &idx);
 
   void updateRow(QModelIndex const &idx);
-  void populate(EbmlMaster &master);
+  void populate(libebml::EbmlMaster &master);
   void reset();
   void retranslateUi();
 
@@ -64,20 +62,20 @@ public:
 protected:
   void setEditionRowText(QList<QStandardItem *> const &rowItems);
   void setChapterRowText(QList<QStandardItem *> const &rowItems);
-  void populate(EbmlMaster &master, QModelIndex const &parentIdx);
+  void populate(libebml::EbmlMaster &master, QModelIndex const &parentIdx);
   QList<QStandardItem *> itemsForRow(QModelIndex const &idx);
-  void cloneElementsForRetrieval(QModelIndex const &parentIdx, EbmlMaster &target);
+  void cloneElementsForRetrieval(QModelIndex const &parentIdx, libebml::EbmlMaster &target);
   void duplicateTree(QModelIndex const &destParentIdx, int destRow, QModelIndex const &srcIdx);
 
-  qulonglong registerElement(std::shared_ptr<EbmlMaster> const &element);
+  qulonglong registerElement(std::shared_ptr<libebml::EbmlMaster> const &element);
   qulonglong registryIdFromItem(QStandardItem *item);
 
 protected:
   static QList<QStandardItem *> newRowItems();
 
 public:
-  static QString chapterDisplayName(KaxChapterAtom &chapter);
-  static QString chapterNameForLanguage(KaxChapterAtom &chapter, std::string const &language);
+  static QString chapterDisplayName(libmatroska::KaxChapterAtom &chapter);
+  static QString chapterNameForLanguage(libmatroska::KaxChapterAtom &chapter, std::string const &language);
 };
 
 }}}
