@@ -43,10 +43,11 @@
 #include "mkvtoolnix-gui/util/tree.h"
 #include "mkvtoolnix-gui/util/widget.h"
 
-namespace mtx { namespace gui { namespace ChapterEditor {
-
+using namespace libmatroska;
 using namespace mtx::gui;
 
+namespace mtx { namespace gui { namespace ChapterEditor {
+
 TabPrivate::TabPrivate(Tab &tab,
                        QString const &pFileName)
   : ui{new Ui::Tab}
@@ -328,7 +329,7 @@ Tab::readFileEndTimestampForMatroska() {
   kax_file_c fileKax{fileIo};
   fileKax.enable_reporting(false);
 
-  auto cluster = std::shared_ptr<KaxCluster>(fileKax.read_next_cluster());
+  auto cluster = fileKax.read_next_cluster();
   if (!cluster) {
     qDebug() << "readFileEndTimestampForMatroska: no cluster found";
     return true;
@@ -1039,7 +1040,7 @@ Tab::setNameControlsFromStorage(QModelIndex const &idx) {
   if (!display)
     return false;
 
-  auto language = Q(FindChildValue<KaxChapterLanguage>(display, std::string{"eng"}));
+  auto language = Q(FindChildValue<KaxChapterLanguage>(display, "eng"s));
 
   p->ui->leChName->setText(Q(GetChildValue<KaxChapterString>(display)));
   p->ui->cbChNameLanguage->setAdditionalItems(usedNameLanguages())
@@ -1656,7 +1657,7 @@ Tab::changeChapterName(QModelIndex const &parentIdx,
     if (!kDisplay)
       continue;
 
-    auto language = FindChildValue<KaxChapterLanguage>(kDisplay, std::string{"eng"});
+    auto language = FindChildValue<KaxChapterLanguage>(kDisplay, "eng"s);
     if (   (RenumberSubChaptersParametersDialog::NameMatch::All == nameMatchingMode)
         || (Q(language)                                         == languageOfNamesToReplace))
       GetChild<KaxChapterString>(*kDisplay).SetValue(name);
