@@ -35,6 +35,8 @@ Tool::Tool(QWidget *parent,
 {
   // Setup UI controls.
   ui->setupUi(this);
+
+  MainWindow::get()->registerSubWindowWidget(*this, *ui->editors);
 }
 
 Tool::~Tool() {
@@ -176,8 +178,9 @@ Tool::openFilesFromCommandLine(QStringList const &fileNames) {
 void
 Tool::selectFileToOpen() {
   auto fileNames = Util::getOpenFileNames(this, QY("Open files in chapter editor"), Util::Settings::get().lastOpenDirPath(),
-                                          QY("Supported file types")           + Q(" (*.cue *.mpls *.mkv *.mka *.mks *.mk3d *.txt *.xml);;") +
+                                          QY("Supported file types")           + Q(" (*.cue *.mpls *.mkv *.mka *.mks *.mk3d *.txt *.webm *.xml);;") +
                                           QY("Matroska files")                 + Q(" (*.mkv *.mka *.mks *.mk3d);;") +
+                                          QY("WebM files")                     + Q(" (*.webm);;") +
                                           QY("Blu-ray playlist files")         + Q(" (*.mpls);;") +
                                           QY("XML chapter files")              + Q(" (*.xml);;") +
                                           QY("Simple OGM-style chapter files") + Q(" (*.txt);;") +
@@ -353,13 +356,13 @@ Tool::removeChaptersFromExistingMatroskaFile() {
     return;
   }
 
-  auto idx = analyzer->find(KaxChapters::ClassInfos.GlobalId);
+  auto idx = analyzer->find(libmatroska::KaxChapters::ClassInfos.GlobalId);
   if (-1 == idx) {
     Util::MessageBox::information(this)->title(QY("Removing chapters from existing Matroska file")).text(QY("The file you tried to open (%1) does not contain any chapters.").arg(fileName)).exec();
     return;
   }
 
-  auto result = analyzer->remove_elements(EBML_ID(KaxChapters));
+  auto result = analyzer->remove_elements(EBML_ID(libmatroska::KaxChapters));
 
   if (kax_analyzer_c::uer_success != result) {
     QtKaxAnalyzer::displayUpdateElementResult(this, result, QY("Removing the chapters failed."));
@@ -380,4 +383,13 @@ Tool::forEachTab(std::function<void(Tab &)> const &worker) {
   ui->editors->setCurrentIndex(currentIndex);
 }
 
+std::pair<QString, QString>
+Tool::nextPreviousWindowActionTexts()
+  const {
+  return {
+    QY("&Next chapter editor tab"),
+    QY("&Previous chapter editor tab"),
+  };
+}
+
 }}}
