@@ -17,6 +17,7 @@
 #include "mkvtoolnix-gui/main_window/preferences_dialog.h"
 #include "mkvtoolnix-gui/main_window/prefs_run_program_widget.h"
 #include "mkvtoolnix-gui/merge/additional_command_line_options_dialog.h"
+#include "mkvtoolnix-gui/merge/source_file.h"
 #include "mkvtoolnix-gui/util/file_dialog.h"
 #include "mkvtoolnix-gui/util/message_box.h"
 #include "mkvtoolnix-gui/util/model.h"
@@ -44,7 +45,6 @@ PreferencesDialog::PreferencesDialog(QWidget *parent,
 
   // GUI page
   ui->cbGuiCheckForUpdates->setChecked(m_cfg.m_checkForUpdates);
-  ui->cbGuiDisableAnimations->setChecked(m_cfg.m_disableAnimations);
   ui->cbGuiShowToolSelector->setChecked(m_cfg.m_showToolSelector);
   ui->cbGuiWarnBeforeClosingModifiedTabs->setChecked(m_cfg.m_warnBeforeClosingModifiedTabs);
   ui->cbGuiWarnBeforeAbortingJobs->setChecked(m_cfg.m_warnBeforeAbortingJobs);
@@ -75,6 +75,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent,
   ui->cbMSetAudioDelayFromFileName->setChecked(m_cfg.m_setAudioDelayFromFileName);
   ui->cbMDisableCompressionForAllTrackTypes->setChecked(m_cfg.m_disableCompressionForAllTrackTypes);
   ui->cbMDisableDefaultTrackForSubtitles->setChecked(m_cfg.m_disableDefaultTrackForSubtitles);
+  ui->cbMEnableDialogNormGainRemoval->setChecked(m_cfg.m_mergeEnableDialogNormGainRemoval);
   ui->cbMAlwaysShowOutputFileControls->setChecked(m_cfg.m_mergeAlwaysShowOutputFileControls);
   ui->cbMClearMergeSettings->setCurrentIndex(static_cast<int>(m_cfg.m_clearMergeSettings));
   ui->cbMDefaultAudioTrackLanguage->setAdditionalItems(m_cfg.m_defaultAudioTrackLanguage).setup().setCurrentByData(m_cfg.m_defaultAudioTrackLanguage);
@@ -87,6 +88,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent,
   setupProcessPriority();
   setupPlaylistScanningPolicy();
   setupOutputFileNamePolicy();
+  setupEnableMuxingTracksByType();
   setupEnableMuxingTracksByLanguage();
   setupMergeAddingAppendingFilesPolicy();
   setupTrackPropertiesLayout();
@@ -185,8 +187,9 @@ PreferencesDialog::setupPageSelector(Page pageToShow) {
                    addItem(Page::OftenUsedSelections, pGui,    QY("Often used selections"));
   auto pMerge    = addItem(Page::Merge,               nullptr, QY("Multiplexer"),           "merge");
                    addItem(Page::DefaultValues,       pMerge,  QY("Default values"));
-                   addItem(Page::Output,              pMerge,  QY("Output"));
-                   addItem(Page::EnablingTracks,      pMerge,  QY("Enabling tracks"));
+                   addItem(Page::DeriveTrackLanguage, pMerge,  QY("Deriving track languages"));
+                   addItem(Page::Output,              pMerge,  QY("Destination file name"));
+                   addItem(Page::EnablingTracks,      pMerge,  QY("Enabling items"));
                    addItem(Page::Playlists,           pMerge,  QY("Playlists"));
                    addItem(Page::Info,                nullptr, QY("Info tool"),             "document-preview-archive");
                    addItem(Page::HeaderEditor,        nullptr, QY("Header editor"),         "document-edit");
@@ -213,7 +216,6 @@ PreferencesDialog::setupToolTips() {
                    .arg(QY("This is done at startup and at most once within 24 hours."))
                    .arg(QY("No information is transmitted to the server.")));
 
-  Util::setToolTip(ui->cbGuiDisableAnimations, QY("If checked, several short animations used throughout the program as visual clues for the user will be disabled."));
   Util::setToolTip(ui->cbGuiWarnBeforeClosingModifiedTabs,
                    Q("%1 %2")
                    .arg(QY("If checked, the program will ask for confirmation before closing or reloading tabs that have been modified."))
@@ -275,6 +277,8 @@ PreferencesDialog::setupToolTips() {
                    .arg(QY("Normally mkvmerge will apply additional lossless compression for subtitle tracks for certain codecs."))
                    .arg(QY("Checking this option causes the GUI to set that compression to \"none\" by default for all track types when adding files.")));
 
+  Util::setToolTip(ui->cbMEnableDialogNormGainRemoval, QY("If enabled, removal of dialog normalization gain will be enabled for all audio tracks for which removal is supported."));
+
   Util::setToolTip(ui->cbMProbeRangePercentage,
                    Q("%1 %2 %3")
                    .arg(QY("File types such as MPEG program and transport streams (.vob, .m2ts) require parsing a certain amount of data in order to detect all tracks contained in the file."))
@@ -328,6 +332,15 @@ PreferencesDialog::setupToolTips() {
                    .arg(QYH("When the user adds such a file the track's language input is set to the language property from the source file."))
                    .arg(QYH("If the source file contains no such property for a subtitle track, then the language can be derived from the file name if it matches certain patterns (e.g. '…[ger]…' for German)."))
                    .arg(QYH("Depending on this setting the language can also be derived from the file name if the language in the source file is 'undetermined' ('und').")));
+  Util::setToolTip(ui->leMDeriveTrackLanguageCustomRegex,
+                   Q("<p>%1 %2 %3</p><p>%4</p><p>%5</p>")
+                   .arg(QYH("A regular expression is used for matching the file name against a list of recognized languages limited by characters such as '.' or '['…']'."))
+                   .arg(QYH("The expression must contain at least one pair of capturing parenthesis."))
+                   .arg(QYH("The first non-empty capturing parenthesis will be used as the language."))
+                   .arg(QYH("The following placeholders can be used to match the list of recognized languages: '<ISO_639_1_CODES>', '<ISO_639_2_CODES>' and '<LANGUAGE_NAMES>'."))
+                   .arg(QYH("Only English language names are supported.")));
+  Util::setToolTip(ui->pbMDeriveTrackLanguageRevertCustomRegex, QY("Revert the regular expression to its default value."));
+  ui->tbMDeriveTrackLanguageRecognizedLanguages->setToolTips(QY("Only the languages in the 'selected' list on the right will be recognized as track languages in file names."));
 
   Util::setToolTip(ui->cbMDefaultAudioTrackLanguage,
                    Q("<p>%1 %2</p><p>%3 %4</p>")
@@ -377,6 +390,7 @@ PreferencesDialog::setupToolTips() {
                    .arg(QY("This is done only if there is already a file whose name matches the unmodified destination file name.")));
   Util::setToolTip(ui->cbMAutoClearOutputFileName, QY("If this option is enabled, the GUI will always clear the \"destination file name\" input box whenever the last source file is removed."));
 
+  ui->tbMEnableMuxingTracksByType->setToolTips(QY("Only items whose type is in the 'selected' list on the right will be set to be copied by default."));
   Util::setToolTip(ui->cbMEnableMuxingTracksByLanguage,
                    Q("<p>%1 %2 %3</p><p>%4</p>")
                    .arg(QYH("When adding source files all tracks are normally set to be copied into the destination file."))
@@ -390,22 +404,19 @@ PreferencesDialog::setupToolTips() {
                                                    QY("Only tracks with a language in this list will be set to be copied by default."));
 
   // Often used XYZ page
-  ui->tbOftenUsedLanguages->setToolTips(QY("The languages in the 'selected' list on the right will be shown at the top of all the language drop-down boxes in the program."),
-                                        QY("The languages in the 'selected' list on the right will be shown at the top of all the language drop-down boxes in the program."));
+  ui->tbOftenUsedLanguages->setToolTips(QY("The languages in the 'selected' list on the right will be shown at the top of all the language drop-down boxes in the program."));
   Util::setToolTip(ui->cbOftenUsedLanguagesOnly,
                    Q("%1 %2")
                    .arg(QYH("If checked, only the list of often used entries will be included in the selections in the program."))
                    .arg(QYH("Otherwise the often used entries will be included first and the full list of all entries afterwards.")));
 
-  ui->tbOftenUsedCountries->setToolTips(QY("The countries in the 'selected' list on the right will be shown at the top of all the country drop-down boxes in the program."),
-                                        QY("The countries in the 'selected' list on the right will be shown at the top of all the country drop-down boxes in the program."));
+  ui->tbOftenUsedCountries->setToolTips(QY("The countries in the 'selected' list on the right will be shown at the top of all the country drop-down boxes in the program."));
   Util::setToolTip(ui->cbOftenUsedCountriesOnly,
                    Q("%1 %2")
                    .arg(QYH("If checked, only the list of often used entries will be included in the selections in the program."))
                    .arg(QYH("Otherwise the often used entries will be included first and the full list of all entries afterwards.")));
 
-  ui->tbOftenUsedCharacterSets->setToolTips(QY("The character sets in the 'selected' list on the right will be shown at the top of all the character set drop-down boxes in the program."),
-                                            QY("The character sets in the 'selected' list on the right will be shown at the top of all the character set drop-down boxes in the program."));
+  ui->tbOftenUsedCharacterSets->setToolTips(QY("The character sets in the 'selected' list on the right will be shown at the top of all the character set drop-down boxes in the program."));
   Util::setToolTip(ui->cbOftenUsedCharacterSetsOnly,
                    Q("%1 %2")
                    .arg(QYH("If checked, only the list of often used entries will be included in the selections in the program."))
@@ -436,6 +447,8 @@ PreferencesDialog::setupConnections() {
   connect(ui->cbMEnableMuxingTracksByLanguage,            &QCheckBox::toggled,                                           ui->cbMEnableMuxingAllSubtitleTracks, &QLabel::setEnabled);
   connect(ui->cbMEnableMuxingTracksByLanguage,            &QCheckBox::toggled,                                           ui->tbMEnableMuxingTracksByLanguage,  &QLabel::setEnabled);
 
+  connect(ui->pbMDeriveTrackLanguageRevertCustomRegex,    &QPushButton::clicked,                                         this,                                 &PreferencesDialog::revertDeriveTrackLanguageFromFileNameRegex);
+
   connect(ui->cbGuiRemoveJobs,                            &QCheckBox::toggled,                                           ui->cbGuiJobRemovalPolicy,            &QComboBox::setEnabled);
   connect(ui->cbGuiRemoveOldJobs,                         &QCheckBox::toggled,                                           this,                                 &PreferencesDialog::adjustRemoveOldJobsControls);
   connect(ui->sbGuiRemoveOldJobsDays,                     static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this,                                 &PreferencesDialog::adjustRemoveOldJobsControls);
@@ -552,6 +565,20 @@ PreferencesDialog::setupOutputFileNamePolicy() {
   enableOutputFileNameControls();
 }
 
+void
+PreferencesDialog::setupEnableMuxingTracksByType() {
+  auto allTypes      = Util::SideBySideMultiSelect::ItemList{};
+  auto selectedTypes = QStringList{};
+
+  for (auto type = static_cast<int>(Merge::TrackType::Min); type <= static_cast<int>(Merge::TrackType::Max); ++type)
+    allTypes << std::make_pair(Merge::Track::nameForType(static_cast<Merge::TrackType>(type)), QString::number(type));
+
+  for (auto type : m_cfg.m_enableMuxingTracksByTheseTypes)
+    selectedTypes << QString::number(static_cast<int>(type));
+
+  ui->tbMEnableMuxingTracksByType->setItems(allTypes, selectedTypes);
+}
+
 void
 PreferencesDialog::setupEnableMuxingTracksByLanguage() {
   auto widgets = QList<QWidget *>{} << ui->lMEnableMuxingAllTracksOfType << ui->cbMEnableMuxingAllVideoTracks << ui->cbMEnableMuxingAllAudioTracks << ui->cbMEnableMuxingAllSubtitleTracks << ui->tbMEnableMuxingTracksByLanguage;
@@ -632,6 +659,11 @@ PreferencesDialog::setupDerivingTrackLanguagesFromFileName() {
   setupComboBox(*ui->cbMDeriveAudioTrackLanguageFromFileName,    m_cfg.m_deriveAudioTrackLanguageFromFileNamePolicy);
   setupComboBox(*ui->cbMDeriveVideoTrackLanguageFromFileName,    m_cfg.m_deriveVideoTrackLanguageFromFileNamePolicy);
   setupComboBox(*ui->cbMDeriveSubtitleTrackLanguageFromFileName, m_cfg.m_deriveSubtitleTrackLanguageFromFileNamePolicy);
+
+  ui->leMDeriveTrackLanguageCustomRegex->setText(m_cfg.m_regexForDerivingTrackLanguagesFromFileNames);
+
+  ui->tbMDeriveTrackLanguageRecognizedLanguages->setItems(QList<Util::SideBySideMultiSelect::Item>::fromVector(QVector<Util::SideBySideMultiSelect::Item>::fromStdVector(App::iso639Languages())),
+                                                          m_cfg.m_recognizedTrackLanguagesInFileNames);
 }
 
 void
@@ -680,7 +712,6 @@ PreferencesDialog::save() {
   m_cfg.m_uiFontFamily                                  = ui->fcbGuiFontFamily->currentFont().family();
   m_cfg.m_uiFontPointSize                               = ui->sbGuiFontPointSize->value();
   m_cfg.m_checkForUpdates                               = ui->cbGuiCheckForUpdates->isChecked();
-  m_cfg.m_disableAnimations                             = ui->cbGuiDisableAnimations->isChecked();
   m_cfg.m_showToolSelector                              = ui->cbGuiShowToolSelector->isChecked();
   m_cfg.m_warnBeforeClosingModifiedTabs                 = ui->cbGuiWarnBeforeClosingModifiedTabs->isChecked();
   m_cfg.m_warnBeforeAbortingJobs                        = ui->cbGuiWarnBeforeAbortingJobs->isChecked();
@@ -707,6 +738,7 @@ PreferencesDialog::save() {
   m_cfg.m_setAudioDelayFromFileName                     = ui->cbMSetAudioDelayFromFileName->isChecked();
   m_cfg.m_disableCompressionForAllTrackTypes            = ui->cbMDisableCompressionForAllTrackTypes->isChecked();
   m_cfg.m_disableDefaultTrackForSubtitles               = ui->cbMDisableDefaultTrackForSubtitles->isChecked();
+  m_cfg.m_mergeEnableDialogNormGainRemoval              = ui->cbMEnableDialogNormGainRemoval->isChecked();
   m_cfg.m_mergeAddingAppendingFilesPolicy               = static_cast<Util::Settings::MergeAddingAppendingFilesPolicy>(ui->cbMAddingAppendingFilesPolicy->currentData().toInt());
   m_cfg.m_mergeAlwaysShowOutputFileControls             = ui->cbMAlwaysShowOutputFileControls->isChecked();
   m_cfg.m_mergeTrackPropertiesLayout                    = ui->rbMTrackPropertiesLayoutHorizontalScrollArea->isChecked() ? Util::Settings::TrackPropertiesLayout::HorizontalScrollArea
@@ -725,6 +757,8 @@ PreferencesDialog::save() {
   m_cfg.m_deriveAudioTrackLanguageFromFileNamePolicy    = static_cast<Util::Settings::DeriveLanguageFromFileNamePolicy>(ui->cbMDeriveAudioTrackLanguageFromFileName   ->currentData().toInt());
   m_cfg.m_deriveVideoTrackLanguageFromFileNamePolicy    = static_cast<Util::Settings::DeriveLanguageFromFileNamePolicy>(ui->cbMDeriveVideoTrackLanguageFromFileName   ->currentData().toInt());
   m_cfg.m_deriveSubtitleTrackLanguageFromFileNamePolicy = static_cast<Util::Settings::DeriveLanguageFromFileNamePolicy>(ui->cbMDeriveSubtitleTrackLanguageFromFileName->currentData().toInt());
+  m_cfg.m_regexForDerivingTrackLanguagesFromFileNames   = ui->leMDeriveTrackLanguageCustomRegex->text();
+  m_cfg.m_recognizedTrackLanguagesInFileNames           = ui->tbMDeriveTrackLanguageRecognizedLanguages->selectedItemValues();
 
   m_cfg.m_scanForPlaylistsPolicy                        = static_cast<Util::Settings::ScanForPlaylistsPolicy>(ui->cbMScanPlaylistsPolicy->currentIndex());
   m_cfg.m_minimumPlaylistDuration                       = ui->sbMMinPlaylistDuration->value();
@@ -771,6 +805,10 @@ PreferencesDialog::save() {
       m_cfg.m_runProgramConfigurations << cfg;
   }
 
+  m_cfg.m_enableMuxingTracksByTheseTypes.clear();
+  for (auto const &type : ui->tbMEnableMuxingTracksByType->selectedItemValues())
+    m_cfg.m_enableMuxingTracksByTheseTypes << static_cast<Merge::TrackType>(type.toInt());
+
   m_cfg.save();
 }
 
@@ -886,7 +924,51 @@ PreferencesDialog::showPage(Page page) {
 }
 
 void
-PreferencesDialog::accept() {
+PreferencesDialog::revertDeriveTrackLanguageFromFileNameRegex() {
+  ui->leMDeriveTrackLanguageCustomRegex->setText(mtx::gui::Merge::SourceFile::defaultRegexForDerivingLanguageFromFileName());
+}
+
+bool
+PreferencesDialog::verifyDeriveTrackLanguageSettings() {
+  if (   (static_cast<Util::Settings::DeriveLanguageFromFileNamePolicy>(ui->cbMDeriveAudioTrackLanguageFromFileName   ->currentData().toInt()) == Util::Settings::DeriveLanguageFromFileNamePolicy::Never)
+      && (static_cast<Util::Settings::DeriveLanguageFromFileNamePolicy>(ui->cbMDeriveVideoTrackLanguageFromFileName   ->currentData().toInt()) == Util::Settings::DeriveLanguageFromFileNamePolicy::Never)
+      && (static_cast<Util::Settings::DeriveLanguageFromFileNamePolicy>(ui->cbMDeriveSubtitleTrackLanguageFromFileName->currentData().toInt()) == Util::Settings::DeriveLanguageFromFileNamePolicy::Never))
+    return true;
+
+  auto pattern = ui->leMDeriveTrackLanguageCustomRegex->text();
+  if (pattern.isEmpty())
+    return true;
+
+  auto regex = QRegularExpression{pattern};
+  if (!regex.isValid()) {
+    showPage(Page::DeriveTrackLanguage);
+    ui->leMDeriveTrackLanguageCustomRegex->setFocus();
+
+    Util::MessageBox::critical(this)
+      ->title(QY("Invalid settings"))
+      .text(QY("The regular expression for deriving the track language from file names is invalid: %1").arg(regex.errorString()))
+      .exec();
+
+    return false;
+  }
+
+  if (ui->tbMDeriveTrackLanguageRecognizedLanguages->selectedItemValues().isEmpty()) {
+    showPage(Page::DeriveTrackLanguage);
+    ui->tbMDeriveTrackLanguageRecognizedLanguages->setFocus();
+
+    Util::MessageBox::critical(this)
+      ->title(QY("Invalid settings"))
+      .text(QY("The list of recognized track languages in file names must not be empty."))
+      .exec();
+
+    return false;
+  }
+
+  return true;
+}
+
+bool
+PreferencesDialog::verifyRunProgramConfigurations() {
   for (auto tabIdx = 0, numTabs = ui->twJobsPrograms->count(); tabIdx < numTabs; ++tabIdx) {
     auto tab   = qobject_cast<PrefsRunProgramWidget *>(ui->twJobsPrograms->widget(tabIdx));
     auto error = tab->validate();
@@ -906,10 +988,17 @@ PreferencesDialog::accept() {
             .arg(QY("Either fix the error or remove the configuration before closing the preferences dialog.").toHtmlEscaped()))
       .exec();
 
-    return;
+    return false;
   }
 
-  QDialog::accept();
+  return true;
+}
+
+void
+PreferencesDialog::accept() {
+  if (   verifyDeriveTrackLanguageSettings()
+      && verifyRunProgramConfigurations())
+    QDialog::accept();
 }
 
 }}
