@@ -24,6 +24,7 @@ public:
     OftenUsedSelections,
     Merge,
     DefaultValues,
+    DeriveTrackLanguage,
     Output,
     EnablingTracks,
     Playlists,
@@ -63,6 +64,7 @@ public slots:
   void setSendersTabTitleForRunProgramWidget();
   void adjustPlaylistControls();
   void adjustRemoveOldJobsControls();
+  void revertDeriveTrackLanguageFromFileNameRegex();
 
   void enableOftendUsedLanguagesOnly();
   void enableOftendUsedCountriesOnly();
@@ -87,6 +89,7 @@ protected:
   void setupPlaylistScanningPolicy();
   void setupOutputFileNamePolicy();
   void setupTrackPropertiesLayout();
+  void setupEnableMuxingTracksByType();
   void setupEnableMuxingTracksByLanguage();
   void setupMergeAddingAppendingFilesPolicy();
   void setupHeaderEditorDroppedFilesPolicy();
@@ -98,6 +101,9 @@ protected:
   void setTabTitleForRunProgramWidget(int tabIdx, QString const &title);
 
   QModelIndex modelIndexForPage(int pageIndex);
+
+  bool verifyDeriveTrackLanguageSettings();
+  bool verifyRunProgramConfigurations();
 };
 
 }}
