@@ -11,26 +11,24 @@
 
 namespace mtx { namespace gui { namespace Merge {
 
-using namespace mtx::gui;
-
 class SourceFile;
 
 class FileIdentificationWorkerPrivate;
 class FileIdentificationWorker : public QObject {
   Q_OBJECT;
 
+protected:
+  MTX_DECLARE_PRIVATE(FileIdentificationWorkerPrivate);
+
+  std::unique_ptr<FileIdentificationWorkerPrivate> const p_ptr;
+
+  explicit FileIdentificationWorker(FileIdentificationWorkerPrivate &p);
+
   enum class Result {
     Wait,
     Continue,
   };
 
-protected:
-  Q_DECLARE_PRIVATE(FileIdentificationWorker);
-
-  QScopedPointer<FileIdentificationWorkerPrivate> const d_ptr;
-
-  explicit FileIdentificationWorker(FileIdentificationWorkerPrivate &d);
-
 public:
   FileIdentificationWorker(QObject *parent = nullptr);
   virtual ~FileIdentificationWorker();
@@ -78,7 +76,7 @@ class FileIdentificationThread : public QThread {
   Q_OBJECT;
 
 protected:
-  QScopedPointer<FileIdentificationWorker> m_worker;
+  std::unique_ptr<FileIdentificationWorker> m_worker;
 
 public:
   FileIdentificationThread(QObject *parent = nullptr);
