@@ -29,6 +29,8 @@
 #include "common/kax_info_p.h"
 #include "mkvtoolnix-gui/util/kax_info.h"
 
+using namespace libmatroska;
+
 namespace mtx { namespace gui { namespace Util {
 
 class KaxInfoPrivate: public mtx::kax_info::private_c {
@@ -177,7 +179,7 @@ KaxInfo::doScanLevel1Elements() {
       if (upper_lvl_el)
         break;
 
-      p->m_in->setFilePointer(l1->GetElementPosition() + kax_file_c::get_element_size(l1.get()));
+      p->m_in->setFilePointer(l1->GetElementPosition() + kax_file_c::get_element_size(*l1));
     }
 
   } catch (mtx::mm_io::exception &ex) {
