@@ -32,6 +32,7 @@ dts_packetizer_c::dts_packetizer_c(generic_reader_c *p_reader,
   , m_previous_header{dtsheader}
   , m_skipping_is_normal{}
   , m_reduce_to_core{get_option_for_track(m_ti.m_reduce_to_core, m_ti.m_id)}
+  , m_remove_dialog_normalization_gain{get_option_for_track(m_ti.m_remove_dialog_normalization_gain, m_ti.m_id)}
   , m_timestamp_calculator{static_cast<int64_t>(m_first_header.core_sampling_frequency)}
   , m_stream_position{}
   , m_packet_position{}
@@ -126,6 +127,7 @@ dts_packetizer_c::set_headers() {
 int
 dts_packetizer_c::process(packet_cptr packet) {
   m_timestamp_calculator.add_timestamp(packet, m_stream_position);
+  m_discard_padding.add_maybe(packet->discard_padding, m_stream_position);
   m_stream_position += packet->data->get_size();
 
   m_packet_buffer.add(packet->data->get_buffer(), packet->data->get_size());
@@ -164,13 +166,18 @@ dts_packetizer_c::process_available_packets() {
     return;
 
   for (auto const &header_and_packet : m_queued_packets) {
-    auto &header           = std::get<0>(header_and_packet);
-    auto &data             = std::get<1>(header_and_packet);
-    auto packet_position   = std::get<2>(header_and_packet);
-    auto samples_in_packet = header.get_packet_length_in_core_samples();
-    auto new_timestamp     = m_timestamp_calculator.get_next_timestamp(samples_in_packet, packet_position);
+    auto &header            = std::get<0>(header_and_packet);
+    auto &data              = std::get<1>(header_and_packet);
+    auto packet_position    = std::get<2>(header_and_packet);
+    auto samples_in_packet  = header.get_packet_length_in_core_samples();
+    auto new_timestamp      = m_timestamp_calculator.get_next_timestamp(samples_in_packet, packet_position);
+    auto packet             = std::make_shared<packet_t>(data, new_timestamp.to_ns(), header.get_packet_length_in_nanoseconds().to_ns());
+    packet->discard_padding = m_discard_padding.get_next(packet_position).get_value_or({});
 
-    add_packet(std::make_shared<packet_t>(data, new_timestamp.to_ns(), header.get_packet_length_in_nanoseconds().to_ns()));
+    if (m_remove_dialog_normalization_gain)
+      mtx::dts::remove_dialog_normalization_gain(data->get_buffer(), data->get_size());
+
+    add_packet(packet);
   }
 
   m_queued_packets.clear();
