@@ -18,6 +18,7 @@
 #include "common/codec.h"
 #include "common/strings/editing.h"
 #include "common/strings/parsing.h"
+#include "common/strings/utf8.h"
 #include "merge/connection_checks.h"
 #include "merge/output_control.h"
 #include "merge/packet_extensions.h"
@@ -28,13 +29,15 @@ using namespace libmatroska;
 textsubs_packetizer_c::textsubs_packetizer_c(generic_reader_c *p_reader,
                                              track_info_c &p_ti,
                                              const char *codec_id,
-                                             bool recode,
-                                             bool is_utf8)
+                                             bool recode)
   : generic_packetizer_c(p_reader, p_ti)
   , m_codec_id{codec_id}
 {
-  if (recode && !is_utf8)
-    m_cc_utf8 = charset_converter_c::init(m_ti.m_sub_charset);
+  if (recode) {
+    m_cc_utf8           = charset_converter_c::init(m_ti.m_sub_charset);
+    m_converter_is_utf8 = charset_converter_c::is_utf8_charset_name(m_cc_utf8->get_charset());
+    m_try_utf8          = m_ti.m_sub_charset.empty();
+  }
 
   set_track_type(track_subtitle);
   if (m_codec_id == MKV_S_TEXTUSF)
@@ -89,10 +92,26 @@ textsubs_packetizer_c::process(packet_cptr packet) {
   auto subs = std::string{reinterpret_cast<char *>(packet->data->get_buffer()), packet->data->get_size()};
   subs      = chomp(normalize_line_endings(subs, m_line_ending_style));
 
-  if (m_cc_utf8)
+  if (m_try_utf8 && !mtx::utf8::is_valid(subs))
+    m_try_utf8 = false;
+
+  auto emit_invalid_utf8_warning = false;
+
+  if (!m_try_utf8 && m_cc_utf8) {
+    if (!m_invalid_utf8_warned && m_converter_is_utf8 && !mtx::utf8::is_valid(subs))
+      emit_invalid_utf8_warning = true;
+
     subs = m_cc_utf8->utf8(subs);
 
-  packet->data = memory_cptr(new memory_c((unsigned char *)subs.c_str(), subs.length(), false));
+  } else if (!m_invalid_utf8_warned && !mtx::utf8::is_valid(subs))
+    emit_invalid_utf8_warning = true;
+
+  if (emit_invalid_utf8_warning) {
+    m_invalid_utf8_warned = true;
+    mxwarn_tid(m_ti.m_fname, m_ti.m_id, boost::format(Y("This text subtitle track contains invalid 8-bit characters outside valid multi-byte UTF-8 sequences. Please specify the correct encoding for this track.\n")));
+  }
+
+  packet->data = memory_c::borrow(subs);
 
   add_packet(packet);
 
