@@ -23,11 +23,12 @@ protected:
   unsigned int m_packetno{};
   boost::optional<unsigned int> m_force_rerender_track_headers_on_packetno;
   charset_converter_cptr m_cc_utf8;
+  bool m_try_utf8{}, m_invalid_utf8_warned{}, m_converter_is_utf8{};
   std::string m_codec_id;
   line_ending_style_e m_line_ending_style{line_ending_style_e::cr_lf};
 
 public:
-  textsubs_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, const char *codec_id, bool recode, bool is_utf8);
+  textsubs_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, const char *codec_id, bool recode = false);
   virtual ~textsubs_packetizer_c();
 
   virtual int process(packet_cptr packet);
