@@ -245,6 +245,7 @@ change_c::execute_delete() {
   unsigned int num_deleted = 0;
   while (m_master->ListSize() > idx) {
     if (m_property.m_callbacks->GlobalId == (*m_master)[idx]->Generic().GlobalId) {
+      delete (*m_master)[idx];
       m_master->Remove(idx);
       ++num_deleted;
     } else
@@ -333,7 +334,7 @@ change_c::validate_deletion_of_mandatory() {
 
 const EbmlSemantic *
 change_c::get_semantic() {
-  return find_ebml_semantic(KaxSegment::ClassInfos, m_property.m_callbacks->GlobalId);
+  return find_ebml_semantic(libmatroska::KaxSegment::ClassInfos, m_property.m_callbacks->GlobalId);
 }
 
 change_cptr
