@@ -18,6 +18,9 @@
 #include "common/command_line.h"
 #include "common/common_pch.h"
 #include "common/mm_io_x.h"
+#include "common/mm_file_io.h"
+#include "common/mm_proxy_io.h"
+#include "common/mm_text_io.h"
 #include "common/mm_write_buffer_io.h"
 #include "common/strings/editing.h"
 #include "common/strings/parsing.h"
@@ -72,7 +75,7 @@ main(int argc,
   try {
     in = mm_io_cptr(new mm_file_io_c(argv[2]));
     if (mode != 'e')
-      intext = mm_io_cptr(new mm_text_io_c(in.get(), false));
+      intext = std::make_shared<mm_text_io_c>(in);
   } catch (mtx::mm_io::exception &ex) {
     mxerror(boost::format(Y("The file '%1%' could not be opened for reading: %2%.\n")) % argv[2] % ex);
   }
@@ -85,7 +88,7 @@ main(int argc,
   }
 
   in->save_pos();
-  in->setFilePointer(0, seek_end);
+  in->setFilePointer(0, libebml::seek_end);
   size = in->getFilePointer();
   in->restore_pos();
 
